# Generated by Django 2.1.8 on 2019-07-03 09:56

import allink_core.core.models.fields
import aldryn_translation_tools.models
import allink_core.core.models.mixins
import cms.models.fields
from django.conf import settings
import django.contrib.postgres.fields
from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone
import djangocms_text_ckeditor.fields
import filer.fields.image
import model_utils.fields
import parler.models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.FILER_IMAGE_MODEL),
        ('allink_categories', '0001_initial'),
        ('cms', '0022_auto_20180620_1551'),
    ]

    operations = [
        migrations.CreateModel(
            name='News',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('start', models.DateTimeField(blank=True, null=True, verbose_name='start')),
                ('end', models.DateTimeField(blank=True, null=True, verbose_name='end')),
                ('created', model_utils.fields.AutoCreatedField(default=django.utils.timezone.now, editable=False, verbose_name='created')),
                ('modified', model_utils.fields.AutoLastModifiedField(default=django.utils.timezone.now, editable=False, verbose_name='modified')),
                ('status', models.IntegerField(choices=[(1, 'active'), (2, 'inactive')], default=1, verbose_name='status')),
                ('template', models.CharField(blank=True, help_text='Choose a template.', max_length=50, null=True, verbose_name='Template')),
                ('sort_order', models.PositiveIntegerField(db_index=True, default=0, editable=False)),
                ('categories', models.ManyToManyField(blank=True, to='allink_categories.AllinkCategory')),
                ('content_placeholder', cms.models.fields.PlaceholderField(editable=False, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='news_news_content_placeholder', slotname='news_content', to='cms.Placeholder')),
                ('header_placeholder', cms.models.fields.PlaceholderField(editable=False, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='news_news_header_placeholder', slotname='news_header', to='cms.Placeholder')),
                ('og_image', filer.fields.image.FilerImageField(blank=True, help_text='og: image is used when shared on Facebook/ Twitter etc. (Min. 1200 x 630 px)<br>Page: 1. fallback is teaser_image, 2. fallback is field allink_config.default_og_image.<br>App: 1. fallback = preview_image 2. fallback is teaser_image, 3. fallback is defined in allink_config.default_og_image.<br>', null=True, on_delete=django.db.models.deletion.PROTECT, related_name='news_news_og_image', to=settings.FILER_IMAGE_MODEL, verbose_name='og:Image')),
                ('preview_image', filer.fields.image.FilerImageField(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='news_news_preview_image', to=settings.FILER_IMAGE_MODEL, verbose_name='Preview Image')),
                ('teaser_image', filer.fields.image.FilerImageField(blank=True, help_text='Optional field for teaser image. og: properties are used when shared on Facebook/ Twitter etc. (Min. 1200 x 630 px)<br>Also used as "meta" property="og:image"<br>Page: 1. fallback is allink_config.default_og_image.<br>App: 1. fallback = preview_image 2. fallback is defined in allink_config.default_og_image.<br>', null=True, on_delete=django.db.models.deletion.PROTECT, related_name='news_news_teaser_image', to=settings.FILER_IMAGE_MODEL, verbose_name='Teaser image')),
            ],
            options={
                'verbose_name': 'News entry',
                'verbose_name_plural': 'News',
                'ordering': ('sort_order',),
                'abstract': False,
            },
            bases=(aldryn_translation_tools.models.TranslationHelperMixin, allink_core.core.models.mixins.AllinkTranslatedAutoSlugifyMixin, allink_core.core.models.mixins.AllinkInvalidatePlaceholderCacheMixin, allink_core.core.models.mixins.AllinkMetaTagMixin, allink_core.core.models.mixins.AllinkTeaserMixin, parler.models.TranslatableModelMixin, models.Model),
        ),
        migrations.CreateModel(
            name='NewsAppContentPlugin',
            fields=[
                ('manual_filtering', models.CharField(blank=True, max_length=50, null=True)),
                ('manual_ordering', models.CharField(blank=True, max_length=50, null=True)),
                ('filter_fields', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(max_length=50), blank=True, default=None, null=True, size=None)),
                ('template', models.CharField(help_text='Choose a template.', max_length=50, verbose_name='Template')),
                ('category_navigation_enabled', models.BooleanField(default=False, help_text='If checked, a filter navigation with all selected categories is displayed.<br>Please note: A category is only displayed if it contains items.', verbose_name='Show category navigation')),
                ('category_navigation_all', models.BooleanField(default=False, help_text='If checked, a category "all" in filter navigation is displayed.', verbose_name='Show category "all"')),
                ('softpage_enabled', models.BooleanField(default=True, help_text='If checked, the detail view of an entry will be displayed in a "softpage". Otherwise the page will be reloaded.', verbose_name='Show detailed information in Softpage')),
                ('detail_link_enabled', models.BooleanField(default=True, help_text='If checked, a link/button to the detail view will be displayed.', verbose_name='Show detail link')),
                ('items_per_row', models.IntegerField(choices=[(1, 1), (2, 2), (3, 3), (4, 4)], default=3, help_text='Only applied if a "Grid" template has been selected.', verbose_name='Grid items per row')),
                ('paginated_by', models.IntegerField(default=0, help_text='Limit the number of entries (in case of the "load more" pagination type: entries per page). Default is "0" (show all entries)', verbose_name='Max. entries per page')),
                ('pagination_type', models.CharField(choices=[('no', 'None'), ('load', 'Add "Load more"-Button'), ('load_rest', 'Add "Load all"-Button')], default=('no', 'None'), max_length=50, verbose_name='Pagination Type')),
                ('load_more_button_text', models.CharField(blank=True, help_text='If left blank, a default text will be used. <br>Note: Should the default text be adjusted site-wide, please contact the project manager (such changes can be made on a code level)', max_length=255, null=True, verbose_name='Text for "Load .."-Button')),
                ('detail_link_text', models.CharField(blank=True, help_text='If left blank, a default text will be used.<br>Note: Should the default text be adjusted site-wide, please contact the project manager (such changes can be made on a code level)', max_length=255, null=True, verbose_name='Text for "Detail"-Link')),
                ('project_css_classes', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(blank=True, max_length=50, null=True), blank=True, null=True, size=None)),
                ('cmsplugin_ptr', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, related_name='news_newsappcontentplugin', serialize=False, to='cms.CMSPlugin')),
                ('apphook_page', cms.models.fields.PageField(blank=True, help_text='If provided, this Apphook-Page will be used to generate the detail link.', null=True, on_delete=django.db.models.deletion.PROTECT, to='cms.Page', verbose_name='Apphook Page')),
                ('categories', models.ManyToManyField(blank=True, to='allink_categories.AllinkCategory')),
                ('categories_and', models.ManyToManyField(blank=True, related_name='news_newsappcontentplugin_categories_and', to='allink_categories.AllinkCategory')),
                ('category_navigation', models.ManyToManyField(blank=True, help_text='You can explicitly define the categories for the category navigation here. This will override the automatically set of categories (either the one generated from "Filter & Ordering" or "Manual entries")', related_name='news_newsappcontentplugin_category_navigation', to='allink_categories.AllinkCategory', verbose_name='Categories for Navigation')),
                ('manual_entries', allink_core.core.models.fields.SortedM2MModelField(blank=True, help_text='Select and arrange specific entries, or, leave blank to select all. (If manual entries are selected the category filtering will be ignored.)', to='news.News')),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin',),
        ),
        migrations.CreateModel(
            name='NewsTranslation',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('language_code', models.CharField(db_index=True, max_length=15, verbose_name='Language')),
                ('og_title', models.CharField(blank=True, default='', help_text='title-tag is used when shared on Facebook/ Twitter etc.<br>Also used to overwrite "meta property="og:image.."" and title-tag<br>Page: fallback is field "title" of the page.<br>App: fallback is field "title".', max_length=255, verbose_name='og:title | <title> Tag')),
                ('og_description', models.TextField(blank=True, default='', help_text='Description is used when shared on Facebook/ Twitter etc.<br>Also used to overwrite  "meta" property="og:description" .. and "meta name="description"<br>Page: fallback is field "teaser_description" of the page, if set. Otherwise empty.<br>App: fallback is field "lead", if set. Otherwise empty.', max_length=255, verbose_name='og:description | meta description')),
                ('teaser_title', models.CharField(blank=True, default='', help_text='Page: fallback is field "title" of the page.<br>App: fallback is field "title".', max_length=255, verbose_name='Teaser title')),
                ('teaser_technical_title', models.CharField(blank=True, default='', help_text='Page: no fallback.<br>App: fallback is hardcoded per app in the teaser_dict.', max_length=255, verbose_name='Teaser technical title')),
                ('teaser_description', models.TextField(blank=True, default='', help_text='Page: no fallback.<br>App: fallback is field "lead".', verbose_name='Teaser description')),
                ('teaser_link_text', models.CharField(blank=True, default='', help_text='Page: no fallback.<br>App: fallback is hardcoded per app in the teaser_dict.', max_length=255, verbose_name='Teaser link text')),
                ('title', models.CharField(max_length=255)),
                ('slug', models.SlugField(blank=True, default='', help_text='Leave blank to auto-generate a unique slug.', max_length=255, verbose_name='Slug')),
                ('lead', djangocms_text_ckeditor.fields.HTMLField(blank=True, help_text='Teaser text that in some cases is used in the list view and/or in the detail view.', null=True, verbose_name='Lead Text')),
                ('master', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='translations', to='news.News')),
            ],
            options={
                'abstract': False,
            },
        ),
    ]



# Generated by Django 2.1.8 on 2019-07-02 17:18

import cms.models.fields
from django.conf import settings
import django.contrib.postgres.fields
from django.db import migrations, models
import django.db.models.deletion
import djangocms_attributes_field.fields
import filer.fields.file
import filer.fields.image


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('filer', '0011_auto_20190418_0137'),
        ('cms', '0022_auto_20180620_1551'),
        migrations.swappable_dependency(settings.FILER_IMAGE_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='AllinkImagePlugin',
            fields=[
                ('link_object_id', models.IntegerField(help_text='To which object directs the url.', null=True)),
                ('link_model', models.CharField(help_text='Dotted Path to referenced Model', max_length=300, null=True)),
                ('link_url_name', models.CharField(help_text='Name of the App-URL to use.', max_length=64, null=True)),
                ('link_url_kwargs', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(blank=True, max_length=50, null=True), blank=True, help_text='Keyword arguments used to reverse url.', null=True, size=None)),
                ('link_url', models.URLField(blank=True, default='', help_text='Provide a valid URL to an external website.', max_length=500, verbose_name='External link')),
                ('link_mailto', models.EmailField(blank=True, max_length=255, null=True, verbose_name='Email address')),
                ('link_phone', models.CharField(blank=True, max_length=255, null=True, verbose_name='Phone')),
                ('link_anchor', models.CharField(blank=True, help_text='Appends the value only after the internal or external link.<br>Do <strong>not</strong> include a preceding "#" symbol.', max_length=255, verbose_name='Anchor')),
                ('link_target', models.IntegerField(blank=True, choices=[(1, 'New window'), (2, 'Softpage (large)'), (3, 'Softpage (small)'), (4, 'Lightbox (Forms)'), (5, 'Lightbox (Image)'), (6, 'Lightbox (Default)')], null=True, verbose_name='Link Target')),
                ('link_special', models.CharField(blank=True, max_length=255, null=True, verbose_name='Special Links')),
                ('link_attributes', djangocms_attributes_field.fields.AttributesField(blank=True, default=dict, verbose_name='Attributes')),
                ('ratio', models.CharField(blank=True, max_length=50, null=True, verbose_name='Ratio')),
                ('bg_enabled', models.BooleanField(blank=True, default=True, help_text='Show default image placeholder background color.<br><strong>Important:</strong> Disabling this option results in a transparent background even if a specific color is set (this makes sense when a transparent PNG image is used)', verbose_name='Placeholder Background Color')),
                ('icon_enabled', models.BooleanField(blank=True, default=True, help_text='Show the icon that is used as long as the image is loading.<br><strong>Important:</strong> Disable this option if a transparent PNG image is used.', verbose_name='Loader Icon')),
                ('bg_color', models.CharField(blank=True, max_length=50, null=True, verbose_name='Set a predefined background color')),
                ('caption_text', models.TextField(blank=True, help_text='Provide a description, attribution, copyright or other information.', verbose_name='Caption text')),
                ('attributes', djangocms_attributes_field.fields.AttributesField(blank=True, default=dict, verbose_name='Attributes')),
                ('project_css_classes', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(blank=True, max_length=50, null=True), blank=True, null=True, size=None)),
                ('width_alias', models.CharField(blank=True, max_length=50, null=True, verbose_name='Width Alias')),
                ('cmsplugin_ptr', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, related_name='allink_image_allinkimageplugin', serialize=False, to='cms.CMSPlugin')),
                ('link_apphook_page', cms.models.fields.PageField(help_text='If provided, overrides the external link.', null=True, on_delete=django.db.models.deletion.PROTECT, related_name='allink_image_allinkimageplugin_app_legacy_redirects', to='cms.Page', verbose_name='New Apphook-Page')),
                ('link_file', filer.fields.file.FilerFileField(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='filer.File', verbose_name='file')),
                ('link_page', cms.models.fields.PageField(help_text='If provided, overrides the external link and New Apphook-Page.', null=True, on_delete=django.db.models.deletion.PROTECT, to='cms.Page', verbose_name='New Page')),
                ('picture', filer.fields.image.FilerImageField(null=True, on_delete=django.db.models.deletion.PROTECT, related_name='allink_image_allinkimageplugin_picture', to=settings.FILER_IMAGE_MODEL, verbose_name='Image')),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin', models.Model),
        ),
    ]



# -*- coding: utf-8 -*-
from django import forms
from django.contrib import admin
from django.utils.translation import ugettext_lazy as _, get_language
from cms.plugin_base import CMSPluginBase
from cms.plugin_pool import plugin_pool

from allink_core.core_apps.allink_cms.models import AllinkPageChooserPlugin, AllinkPage, AllinkLanguageChooserPlugin


class AllinkPageChooserPluginForm(forms.ModelForm):

    class Meta:
        model = AllinkPageChooserPlugin
        exclude = ()


class AllinkPageInline(admin.StackedInline):
    model = AllinkPage
    extra = 0
    verbose_name = 'Page'
    verbose_name_plural = 'Pages'


@plugin_pool.register_plugin
class CMSAllinkPageChooserPlugin(CMSPluginBase):
    model = AllinkPageChooserPlugin

    name = _('Page Chooser')
    module = _('Generic')
    cache = False
    form = AllinkPageChooserPluginForm
    inlines = [AllinkPageInline, ]

    def get_render_template(self, context, instance, placeholder):
        return 'allink_cms/plugins/pagechooser/content.html'

    def render(self, context, instance, placeholder):
        object_list = []
        for page in instance.allinkpage_set.all().order_by('id'):
            if page.page.is_published(get_language()):
                if page.just_descendants:
                    [object_list.append(p) for p in page.page.get_descendants()]
                else:
                    object_list.append(page.page)

        context['object_list'] = object_list
        context['instance'] = instance
        return context


@plugin_pool.register_plugin
class CMSAllinkLanguageChooserPlugin(CMSPluginBase):
    model = AllinkLanguageChooserPlugin

    name = _('Language Chooser')
    module = _('Generic')

    def get_render_template(self, context, instance, placeholder):
        if context['request'].is_ajax() or context['request'].toolbar.edit_mode_active:
            return 'allink_cms/plugins/languagechooser/content.html'
        else:
            return 'allink_cms/plugins/languagechooser/content_skeleton.html'



# -*- coding: utf-8 -*-
from django import forms
from django.contrib.admin.widgets import FilteredSelectMultiple
from parler.forms import TranslatableModelForm


class AllinkCategoryAdminForm(TranslatableModelForm):
    """
    TranslatableModelForm used in combination with AllinkCategoryModel
    """
    def __init__(self, *args, **kwargs):
        super(AllinkCategoryAdminForm, self).__init__(*args, **kwargs)
        # if app uses categories, populate 'categories' field
        if self.instance.__class__.get_can_have_categories():
            self.fields['categories'] = forms.ModelMultipleChoiceField(
                label='Categories',
                widget=FilteredSelectMultiple(
                    verbose_name='Categories',
                    is_stacked=True
                ),
                required=True,
                queryset=self.instance.get_relevant_categories()
            )



# -*- coding: utf-8 -*-
from django.db import models
from cms.models.fields import PageField
from cms.models.fields import PlaceholderField
from model_utils.fields import AutoCreatedField
from parler.models import TranslatedField
from filer.fields.image import FilerImageField
from djangocms_text_ckeditor.fields import HTMLField
from allink_core.core.models.fields import SortedM2MModelField

from allink_core.core.models import (
    AllinkCategoryFieldsModel,
    AllinkBaseTranslatableModel,
    AllinkBaseAppContentPlugin,
    AllinkBaseTranslatedFieldsModel,
    AllinkTimeFramedModel,
)
from allink_core.core.loading import get_class

AllinkNewsManager = get_class('news.managers', 'AllinkNewsManager')


class BaseNews(AllinkTimeFramedModel, AllinkCategoryFieldsModel, AllinkBaseTranslatableModel):
    TEASER_FIELD_FALLBACK_CONF = {
        'teaser_image': [
            {'model': 'self', 'field': 'teaser_image', },
            {'model': 'self', 'field': 'preview_image', },
        ],
        'teaser_title': [
            {'model': 'self', 'field': 'teaser_title', },
            {'model': 'self', 'field': 'title', },
        ],
        'teaser_technical_title': [
            {'model': 'self', 'field': 'teaser_technical_title', },
            {'model': 'self', 'field': 'entry_date', },
        ],
        'teaser_description': [
            {'model': 'self', 'field': 'teaser_description', },
            {'model': 'self', 'field': 'lead', },
        ],
        'teaser_link_text': [
            {'model': 'self', 'field': 'teaser_link_text', },
            {'model': 'self', 'field': 'TEASER_LINK_TEXT', },
        ],
    }

    slug_source_field_name = 'title'

    title = TranslatedField(any_language=True)
    entry_date = AutoCreatedField('Entry Date', editable=True)
    lead = TranslatedField()

    preview_image = FilerImageField(
        verbose_name='Preview Image',
        blank=True,
        null=True,
        on_delete=models.PROTECT,
        related_name='%(app_label)s_%(class)s_preview_image',
    )
    template = models.CharField(
        'Template',
        help_text='Choose a template.',
        max_length=50,
        blank=True,
        null=True,
    )

    header_placeholder = PlaceholderField('news_header', related_name='%(app_label)s_%(class)s_header_placeholder')
    content_placeholder = PlaceholderField('news_content', related_name='%(app_label)s_%(class)s_content_placeholder')

    objects = AllinkNewsManager()

    class Meta:
        abstract = True
        ordering = ('-entry_date',)
        app_label = 'news'
        verbose_name = 'News entry'
        verbose_name_plural = 'News'

    def __str__(self):
        return '%s - %s' % (self.title, self.entry_date.strftime('%d.%m.%Y %H:%M:%S'))


class BaseNewsTranslation(AllinkBaseTranslatedFieldsModel):
    master = models.ForeignKey(
        'news.News',
        on_delete=models.CASCADE,
        related_name='translations',
        null=True
    )
    title = models.CharField(
        max_length=255
    )
    lead = HTMLField(
        'Lead Text',
        help_text='Teaser text that in some cases is used in the list view and/or in the detail view.',
        blank=True,
        null=True,
    )

    class Meta:
        abstract = True
        app_label = 'news'


class BaseNewsAppContentPlugin(AllinkBaseAppContentPlugin):
    manual_entries = SortedM2MModelField(
        'news.News',
        blank=True,
        help_text=('Select and arrange specific entries, or, leave blank to select all. (If '
                   'manual entries are selected the category filtering will be applied as well.)')
    )
    apphook_page = PageField(
        verbose_name='Apphook Page',
        null=True,
        blank=True,
        on_delete=models.PROTECT,
        help_text='If provided, this Apphook-Page will be used to generate the detail link.',
    )

    def save(self, *args, **kwargs):
        super(BaseNewsAppContentPlugin, self).save(*args, **kwargs)

    class Meta:
        abstract = True
        app_label = 'news'



# -*- coding: utf-8 -*-
from django import forms

from cms.plugin_base import CMSPluginBase
from cms.plugin_pool import plugin_pool

from allink_core.core.utils import get_additional_choices
from allink_core.core_apps.allink_social_icon.models import AllinkSocialIconContainerPlugin, AllinkSocialIconPlugin


class AllinkSocialIconContainerPluginForm(forms.ModelForm):
    class Meta:
        model = AllinkSocialIconContainerPlugin
        exclude = ('page', 'position', 'placeholder', 'language', 'plugin_type')

    def __init__(self, *args, **kwargs):
        super(AllinkSocialIconContainerPluginForm, self).__init__(*args, **kwargs)
        if get_additional_choices('SOCIAL_ICON_CSS_CLASSES'):
            self.fields['project_css_classes'] = forms.MultipleChoiceField(
                widget=forms.CheckboxSelectMultiple(),
                label='Predifined variations for Social Icon Plugin',
                choices=get_additional_choices('SOCIAL_ICON_CSS_CLASSES'),
                required=False,
            )


class AllinkSocialIconPluginForm(forms.ModelForm):
    class Meta:
        model = AllinkSocialIconPlugin
        exclude = ('page', 'position', 'placeholder', 'language', 'plugin_type')

    def __init__(self, *args, **kwargs):
        super(AllinkSocialIconPluginForm, self).__init__(*args, **kwargs)

        if get_additional_choices('SOCIAL_ICONS_CHOICES'):
            self.fields['icon'] = forms.ChoiceField(
                widget=forms.Select(),
                label='Icon choices for Social Icon Plugin',
                choices=get_additional_choices('SOCIAL_ICONS_CHOICES'),
                required=True,
            )


@plugin_pool.register_plugin
class CMSAllinkSocialIconContainerPlugin(CMSPluginBase):
    model = AllinkSocialIconContainerPlugin
    name = 'Social Icon Container'
    module = 'Generic'
    allow_children = True
    child_classes = ['CMSAllinkSocialIconPlugin']
    form = AllinkSocialIconContainerPluginForm

    def get_fieldsets(self, request, obj=None):
        fieldsets = ()
        if get_additional_choices('SOCIAL_ICON_CSS_CLASSES'):
            fieldsets = (
                (None, {
                    'fields': (
                        'project_css_classes',
                    ),
                }),
            )

        return fieldsets

    def get_render_template(self, context, instance, placeholder):
        template = 'allink_social_icon/content.html'
        return template


@plugin_pool.register_plugin
class CMSAllinkSocialIconPlugin(CMSPluginBase):
    model = AllinkSocialIconPlugin
    name = 'Social Icon'
    module = 'Generic'
    allow_children = False
    form = AllinkSocialIconPluginForm
    text_enabled = False

    def get_fieldsets(self, request, obj=None):
        fieldsets = (
            (None, {
                'fields': (
                    'title',
                    'icon',
                    'link',
                ),
            }),
        )

        return fieldsets

    def get_render_template(self, context, instance, placeholder):
        template = 'allink_social_icon/item.html'
        return template



# Generated by Django 2.2.6 on 2019-11-14 18:28

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import filer.fields.image


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.FILER_IMAGE_MODEL),
        ('cms', '0022_auto_20180620_1551'),
    ]

    operations = [
        migrations.CreateModel(
            name='AllinkQuotePlugin',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, related_name='allink_quote_allinkquoteplugin', serialize=False, to='cms.CMSPlugin')),
                ('text', models.TextField(verbose_name='Quote Text')),
                ('author', models.CharField(blank=True, max_length=255, null=True, verbose_name='Author Name')),
                ('author_description', models.CharField(blank=True, max_length=255, null=True, verbose_name='Author Description')),
                ('author_image', filer.fields.image.FilerImageField(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to=settings.FILER_IMAGE_MODEL, verbose_name='Author Image')),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin',),
        ),
    ]



# -*- coding: utf-8 -*-
from django.contrib import admin
from django import forms
from django.utils.translation import ugettext_lazy as _
from cms.admin.placeholderadmin import PlaceholderAdminMixin
from parler.admin import TranslatableAdmin
from allink_core.core.admin import AllinkMediaAdminMixin, AllinkSEOAdminMixin, AllinkCategoryAdminMixin, \
    AllinkTeaserAdminMixin, AllinkCategoryAdminForm
from allink_core.core.loading import get_model
from allink_core.core.utils import get_additional_choices

News = get_model('news', 'News')


class NewsContentAdminForm(AllinkCategoryAdminForm):

    def __init__(self, *args, **kwargs):
        super(NewsContentAdminForm, self).__init__(*args, **kwargs)

        if get_additional_choices('ADDITIONAL_NEWS_DETAIL_TEMPLATES'):
            self.fields['template'] = forms.CharField(
                label='Template',
                widget=forms.Select(choices=get_additional_choices('ADDITIONAL_NEWS_DETAIL_TEMPLATES', blank=True)),
                required=False,
            )
        else:
            self.fields['template'] = forms.CharField(widget=forms.HiddenInput(), required=False)


@admin.register(News)
class NewsAdmin(AllinkMediaAdminMixin, AllinkSEOAdminMixin, AllinkCategoryAdminMixin,
                AllinkTeaserAdminMixin, PlaceholderAdminMixin,
                TranslatableAdmin):
    form = NewsContentAdminForm
    list_display = ('title', 'status', 'all_categories_column','entry_date',)

    def get_fieldsets(self, request, obj=None):
        fieldsets = (
            (None, {
                'fields': (
                    'status',
                    'title',
                    'slug',
                    'entry_date',
                    'template',
                    'preview_image',
                    'lead',
                )
            }),
        )

        fieldsets += (
            ('Published From/To', {
                'classes': ('collapse',),
                'fields': (
                    'start',
                    'end',
                )
            }),
        )

        fieldsets += self.get_category_fieldsets()
        fieldsets += self.get_teaser_fieldsets()
        fieldsets += self.get_seo_fieldsets()
        return fieldsets

    def formfield_for_dbfield(self, db_field, **kwargs):
        if db_field.name == 'lead':
            kwargs['widget'] = forms.Textarea
            kwargs['max_length'] = 400
            kwargs['help_text'] = 'Max. 400 characters.'
        return super(NewsAdmin, self).formfield_for_dbfield(db_field, **kwargs)



# -*- coding: utf-8 -*-

from allink_core.core.views import AllinkBasePluginLoadMoreView, AllinkBaseDetailView
from allink_core.core.loading import get_model


People = get_model('people', 'People')
PeopleAppContentPlugin = get_model('people', 'PeopleAppContentPlugin')


class PeoplePluginLoadMore(AllinkBasePluginLoadMoreView):
    model = People
    plugin_model = PeopleAppContentPlugin


class PeopleDetail(AllinkBaseDetailView):
    model = People



# Generated by Django 2.1.8 on 2019-07-02 17:18

from django.conf import settings
import django.contrib.postgres.fields
from django.db import migrations, models
import django.db.models.deletion
import djangocms_attributes_field.fields
import filer.fields.file
import filer.fields.image


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('filer', '0011_auto_20190418_0137'),
        ('cms', '0022_auto_20180620_1551'),
        migrations.swappable_dependency(settings.FILER_IMAGE_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='AllinkVideoEmbedPlugin',
            fields=[
                ('attributes', djangocms_attributes_field.fields.AttributesField(blank=True, default=dict, verbose_name='Attributes')),
                ('project_css_classes', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(blank=True, max_length=50, null=True), blank=True, null=True, size=None)),
                ('cmsplugin_ptr', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, related_name='allink_video_allinkvideoembedplugin', serialize=False, to='cms.CMSPlugin')),
                ('video_id', models.CharField(help_text='Only provide the ID. The correct URL will automatically be generated.<br><br>YouTube: https://www.youtube.com/watch?v=<strong>12345678</strong> (the ID is <strong>12345678</strong>)<br>Vimeo: https://vimeo.com/<strong>12345678</strong> (the ID is <strong>12345678</strong>)', max_length=255, verbose_name='Video ID')),
                ('video_service', models.CharField(choices=[('youtube', 'Youtube'), ('vimeo', 'Vimeo')], max_length=50, verbose_name='Video Service')),
                ('ratio', models.CharField(blank=True, max_length=50, null=True, verbose_name='Ratio')),
                ('auto_start_enabled', models.BooleanField(default=False, help_text='<strong>Important:</strong> Autoplaying videos with audio is not recommended. Use wisely. ', verbose_name='Autostart')),
                ('allow_fullscreen_enabled', models.BooleanField(default=True, verbose_name='Allow fullscreen')),
            ],
            options={
                'verbose_name': 'Allink Video Embed',
            },
            bases=('cms.cmsplugin',),
        ),
        migrations.CreateModel(
            name='AllinkVideoFilePlugin',
            fields=[
                ('attributes', djangocms_attributes_field.fields.AttributesField(blank=True, default=dict, verbose_name='Attributes')),
                ('project_css_classes', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(blank=True, max_length=50, null=True), blank=True, null=True, size=None)),
                ('cmsplugin_ptr', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, related_name='allink_video_allinkvideofileplugin', serialize=False, to='cms.CMSPlugin')),
                ('video_file_width', models.IntegerField(blank=True, null=True, verbose_name='Video width')),
                ('video_file_height', models.IntegerField(blank=True, null=True, verbose_name='Video height')),
                ('video_muted_enabled', models.BooleanField(default=True, help_text='Caution: Autoplaying videos with audio is not recommended. Use wisely.', verbose_name='Muted')),
                ('poster_only_on_mobile', models.BooleanField(default=True, help_text='Disable video on mobile devices and only show the start image without video control.', verbose_name='Image Only (Mobile)')),
                ('auto_start_enabled', models.BooleanField(default=True, verbose_name='Autostart')),
                ('allow_fullscreen_enabled', models.BooleanField(default=False, verbose_name='Allow fullscreen')),
                ('video_file', filer.fields.file.FilerFileField(help_text='Recommended video settings:<br><br>Format: mp4<br>Codec: H.264<br>Target Bitrate: 2 (video loads quick and runs smooth)<br>Audio: Not recommended (no audio = smaller file size and less annoyed visitors)<br>File size: Dependent of video length. Generally speaking: Less is more.', null=True, on_delete=django.db.models.deletion.PROTECT, related_name='allink_video_allinkvideofileplugin_video_file', to='filer.File', verbose_name='Video File')),
                ('video_poster_image', filer.fields.image.FilerImageField(help_text='Image that is being displayed while the video is loading. Ideally the very first frame of the video is used, in order to make the transition as smooth as possible.<br><br><strong>Imoprtant:</strong> Make sure the aspect ratio of the image is <strong>exactly the same</strong> as the video, otherwise the video height will shrink or grow when the playback starts.', null=True, on_delete=django.db.models.deletion.PROTECT, related_name='allink_video_allinkvideofileplugin_video_poster_image', to=settings.FILER_IMAGE_MODEL, verbose_name='Video Start Image')),
            ],
            options={
                'verbose_name': 'Allink Video File',
            },
            bases=('cms.cmsplugin',),
        ),
    ]



# -*- coding: utf-8 -*-

from cms.extensions.extension_pool import extension_pool
from allink_core.core.loading import is_model_registered

from allink_core.apps.config.abstract_models import (
    BaseConfig, BaseConfigTranslation, BaseAllinkPageExtension,
    BaseAllinkTitleExtension,
)

__all__ = []

if not is_model_registered('config', 'Config'):
    class Config(BaseConfig):
        pass

    __all__.append('Config')

if not is_model_registered('config', 'ConfigTranslation'):
    class ConfigTranslation(BaseConfigTranslation):
        pass

    __all__.append('ConfigTranslation')

if not is_model_registered('config', 'AllinkPageExtension'):
    class AllinkPageExtension(BaseAllinkPageExtension):
        pass

    __all__.append('AllinkPageExtension')

    extension_pool.register(AllinkPageExtension)

if not is_model_registered('config', 'AllinkTitleExtension'):
    class AllinkTitleExtension(BaseAllinkTitleExtension):
        pass

    __all__.append('AllinkTitleExtension')
    extension_pool.register(AllinkTitleExtension)



# -*- coding: utf-8 -*-
from django.contrib import admin
from django import forms
from adminsortable.admin import SortableAdmin
from cms.admin.placeholderadmin import PlaceholderAdminMixin
from parler.admin import TranslatableAdmin
from allink_core.core.admin import (
    AllinkMediaAdminMixin,
    AllinkSEOAdminMixin,
    AllinkCategoryAdminMixin,
    AllinkTeaserAdminMixin,
)

from .models import DummyApp


@admin.register(DummyApp)
class DummyAppAdmin(AllinkMediaAdminMixin, AllinkSEOAdminMixin, AllinkCategoryAdminMixin,
                    AllinkTeaserAdminMixin, PlaceholderAdminMixin, TranslatableAdmin, SortableAdmin):
    list_display = ('title', 'all_categories_column',)
    list_filter = ('status', 'categories',)

    def get_fieldsets(self, request, obj=None):
        fieldsets = (
            (None, {
                'fields': (
                    'status',
                    'title',
                    'slug',
                    'lead',
                    'preview_image',
                )
            }),
        )

        fieldsets += self.get_category_fieldsets()
        fieldsets += self.get_teaser_fieldsets()
        fieldsets += self.get_seo_fieldsets()
        return fieldsets

    def formfield_for_dbfield(self, db_field, **kwargs):
        if db_field.name == 'lead':
            kwargs['widget'] = forms.Textarea
        return super(DummyAppAdmin, self).formfield_for_dbfield(db_field, **kwargs)



# -*- coding: utf-8 -*-

from allink_core.core.models.managers import AllinkCategoryModelQuerySet


class AllinkPeopleQuerySet(AllinkCategoryModelQuerySet):

    def title_asc(self):
        return self.active()\
            .order_by('last_name', 'id')\
            .distinct('last_name', 'id')

    def title_desc(self):
        return self.active()\
            .order_by('-last_name', 'id')\
            .distinct('last_name', 'id')

    def category(self):
        return self.active()\
            .order_by('categories__tree_id', 'categories__lft', 'last_name')\
            .distinct()


AllinkPeopleManager = AllinkPeopleQuerySet.as_manager



# Generated by Django 2.2.9 on 2020-03-24 13:54

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('allink_content', '0001_initial'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='allinkcontentplugin',
            name='project_on_screen_effect',
        ),
    ]



# Generated by Django 2.1.9 on 2019-07-03 15:28

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import filer.fields.image


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.FILER_IMAGE_MODEL),
        ('allink_teaser', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='allinkteaserplugin',
            name='teaser_description',
            field=models.TextField(blank=True, default='', help_text='Page: no fallback.<br>App: fallback is field "lead".', verbose_name='Teaser description'),
        ),
        migrations.AddField(
            model_name='allinkteaserplugin',
            name='teaser_image',
            field=filer.fields.image.FilerImageField(blank=True, help_text='Optional field for teaser image. og: properties are used when shared on Facebook/ Twitter etc. (Min. 1200 x 630 px)<br>Also used as "meta" property="og:image"<br>Page: 1. fallback is allink_config.default_og_image.<br>App: 1. fallback = preview_image 2. fallback is defined in allink_config.default_og_image.<br>', null=True, on_delete=django.db.models.deletion.PROTECT, related_name='allink_teaser_allinkteaserplugin_teaser_image', to=settings.FILER_IMAGE_MODEL, verbose_name='Teaser image'),
        ),
        migrations.AddField(
            model_name='allinkteaserplugin',
            name='teaser_link_text',
            field=models.CharField(blank=True, default='', help_text='Page: no fallback.<br>App: fallback is hardcoded per app in the teaser_dict.', max_length=255, verbose_name='Teaser link text'),
        ),
        migrations.AddField(
            model_name='allinkteaserplugin',
            name='teaser_technical_title',
            field=models.CharField(blank=True, default='', help_text='Page: no fallback.<br>App: fallback is hardcoded per app in the teaser_dict.', max_length=255, verbose_name='Teaser technical title'),
        ),
        migrations.AddField(
            model_name='allinkteaserplugin',
            name='teaser_title',
            field=models.CharField(blank=True, default='', help_text='Page: fallback is field "title" of the page.<br>App: fallback is field "title".', max_length=255, verbose_name='Teaser title'),
        ),
    ]



# -*- coding: utf-8 -*-
from functools import partial
from django.core.validators import MaxValueValidator
from django.db import models
from django.db.models.fields import PositiveIntegerField
from cms.models.pluginmodel import CMSPlugin
import sortedm2m.fields

from allink_core.core.forms import fields

# Add an app namespace to related_name to avoid field name clashes
# with any other plugins that have a field with the same name as the
# lowercase of the class name of this model.
# https://github.com/divio/django-cms/issues/5030
CMSPluginField = partial(
    models.OneToOneField,
    to=CMSPlugin,
    on_delete=models.CASCADE,
    related_name='%(app_label)s_%(class)s',
    parent_link=True,
)


class Icon(models.CharField):
    default_field_class = fields.Icon
    south_field_class = 'django.db.models.fields.CharField'

    def __init__(self, *args, **kwargs):
        if 'verbose_name' not in kwargs:
            kwargs['verbose_name'] = 'Icon'
        if 'max_length' not in kwargs:
            kwargs['max_length'] = 255
        if 'blank' not in kwargs:
            kwargs['blank'] = True
        if 'default' not in kwargs:
            kwargs['default'] = self.default_field_class.DEFAULT
        super(Icon, self).__init__(*args, **kwargs)

    def formfield(self, **kwargs):
        defaults = {
            'form_class': self.default_field_class,
        }
        defaults.update(kwargs)
        return super(Icon, self).formfield(**defaults)


class ZipCodeField(PositiveIntegerField):
    default_validators = [MaxValueValidator(9999)]
    default_field_class = fields.ZipCode
    description = 'Zip Code Field'

    def formfield(self, **kwargs):
        defaults = {
            'form_class': self.default_field_class,
        }
        defaults.update(kwargs)
        return super(ZipCodeField, self).formfield(**defaults)


class SortedM2MModelField(sortedm2m.fields.SortedManyToManyField):
    default_field_class = fields.SortedM2MFormField

    def formfield(self, **kwargs):
        defaults = {
            'form_class': self.default_field_class,
        }
        defaults.update(kwargs)
        return super(SortedM2MModelField, self).formfield(**defaults)



# -*- coding: utf-8 -*-
from cms.app_base import CMSApp
from cms.apphook_pool import apphook_pool

class PeopleApphook(CMSApp):
    name = "People Apphook"
    app_name = 'people'

    def get_urls(self, page=None, language=None, **kwargs):
        return ['allink_core.apps.people.urls']


apphook_pool.register(PeopleApphook)



# -*- coding: utf-8 -*-
from django.db import models
from cms.models.pluginmodel import CMSPlugin

from allink_core.core.utils import get_additional_templates


class AllinkInfoBoxPlugin(CMSPlugin):
    DISPLAY_DURATION = (
        (0, 'Always visible'),
        (1, '1x'),
        (2, '2x'),
        (3, '3x'),
        (4, '4x'),
        (5, '5x'),
    )

    counter = models.IntegerField(
        'Display duration',
        help_text='After how many times/clicks should the box not be visible anymore',
        choices=DISPLAY_DURATION,
        default=0
    )
    transparent_background = models.BooleanField(
        'Transparent background',
        default=False
    )
    template = models.CharField(
        'Template',
        help_text='Choose a template.',
        max_length=50
    )

    def __str__(self):
        if self.template:
            return '({})'.format(self.template)
        return str(self.pk)

    def get_templates(self):
        templates = ()
        for x, y in get_additional_templates('INFOBOX'):
            templates += ((x, y),)
        return templates



# -*- coding: utf-8 -*-
from django import forms
from cms.plugin_base import CMSPluginBase
from webpack_loader.utils import get_files

from cms.plugin_pool import plugin_pool

from allink_core.core.utils import get_additional_choices, get_ratio_choices
from allink_core.core_apps.allink_video.models import AllinkVideoFilePlugin, AllinkVideoEmbedPlugin
from allink_core.core.admin.mixins import AllinkMediaAdminMixin


class AllinkVideoEmbedPluginForm(forms.ModelForm):

    class Meta:
        model = AllinkVideoEmbedPlugin
        exclude = ('page', 'position', 'placeholder', 'language', 'plugin_type')

    def __init__(self, *args, **kwargs):
        super(AllinkVideoEmbedPluginForm, self).__init__(*args, **kwargs)
        if get_additional_choices('VID_EMBED_CSS_CLASSES'):
            self.fields['project_css_classes'] = forms.MultipleChoiceField(
                widget=forms.CheckboxSelectMultiple(),
                label='Predifined variations for Video Plugin',
                choices=get_additional_choices('VID_EMBED_CSS_CLASSES'),
                required=False,
            )
        self.fields['ratio'] = forms.CharField(
            label='Ratio',
            help_text='This option overrides the default ratio setting for embeded videos.',
            widget=forms.Select(choices=get_ratio_choices()),
            required=False,
        )


class AllinkVideoFilePluginForm(forms.ModelForm):

    class Meta:
        model = AllinkVideoFilePlugin
        exclude = ('page', 'position', 'placeholder', 'language', 'plugin_type')

    def __init__(self, *args, **kwargs):
        super(AllinkVideoFilePluginForm, self).__init__(*args, **kwargs)
        if get_additional_choices('VID_FILE_CSS_CLASSES').__len__() != 0:
            self.fields['project_css_classes'] = forms.MultipleChoiceField(
                widget=forms.CheckboxSelectMultiple(),
                label='Predifined variations for Video Plugin',
                choices=get_additional_choices('VID_FILE_CSS_CLASSES'),
                required=False,
            )


@plugin_pool.register_plugin
class CMSAllinkVideoEmbedPlugin(AllinkMediaAdminMixin, CMSPluginBase):
    model = AllinkVideoEmbedPlugin
    name = 'Video Embed'
    module = 'Generic'
    form = AllinkVideoEmbedPluginForm

    def get_fieldsets(self, request, obj=None):
        fieldsets = [
            (None, {
                'fields': (
                    'video_id',
                    'video_service',
                )
            }),
            ('Video settings', {
                # 'classes': ('collapse',),
                'fields': (
                    'ratio',
                    'auto_start_enabled',
                    'allow_fullscreen_enabled',
                )
            }),
            ('Advanced settings', {
                'classes': ('collapse',),
                'fields': (
                    'attributes',
                    'project_css_classes',
                )
            }),
        ]
        return fieldsets

    def get_render_template(self, context, instance, placeholder):
        template = 'allink_video/embed/content.html'
        return template


@plugin_pool.register_plugin
class CMSAllinkVideoFilePlugin(AllinkMediaAdminMixin, CMSPluginBase):
    model = AllinkVideoFilePlugin
    name = 'Video File'
    module = 'Generic'
    form = AllinkVideoFilePluginForm

    def get_fieldsets(self, request, obj=None):
        fieldsets = [
            (None, {
                'fields': (
                    'video_file',
                    'video_poster_image'
                )
            }),
            ('Video settings', {
                # 'classes': ('collapse',),
                'fields': (
                    'auto_start_enabled',
                    'auto_start_mobile_enabled',
                    'video_muted_enabled',
                    'poster_only_on_mobile',
                    # 'allow_fullscreen_enabled',
                )
            }),
            ('Advanced settings', {
                'classes': ('collapse',),
                'fields': (
                    'attributes',
                    'project_css_classes',
                )
            }),
        ]
        return fieldsets

    def get_render_template(self, context, instance, placeholder):
        template = 'allink_video/file/content.html'
        return template



# -*- coding: utf-8 -*-
from django.contrib import admin
from django.utils.html import format_html
from django import forms
from django.conf import settings
from django.utils.translation import ugettext_lazy as _

from import_export.admin import ImportMixin
from import_export.formats import base_formats

from allink_core.core.utils import base_url
from allink_core.core_apps.allink_legacy_redirect.resources import AllinkLegacyLinkResource
from allink_core.core_apps.allink_legacy_redirect.models import AllinkLegacyLink
from allink_core.core.forms.fields import SelectLinkField
from allink_core.core.forms.mixins import AllinkInternalLinkFieldMixin


class AllinkLegacyChangeAdminForm(AllinkInternalLinkFieldMixin, forms.ModelForm):
    language = forms.ChoiceField(label='Link Target', required=False,
                                 choices=settings.LANGUAGES)

    new_link = SelectLinkField(label='New Page', required=False)

    class Meta:
        model = AllinkLegacyLink
        fields = ['old', 'overwrite', 'active', 'match_subpages']


class AllinkLegacyLinkAdmin(ImportMixin, admin.ModelAdmin):
    list_display = ['old', 'link', 'link_object', 'active', 'match_subpages', 'last_test_result',
                    'last_test_date', 'manual_test']
    readonly_fields = ['last_test_result', 'last_test_date']
    form = AllinkLegacyChangeAdminForm
    resource_class = AllinkLegacyLinkResource
    actions = ['auto_test']
    fields = ['old', 'new_link', 'language', 'overwrite', 'active', 'match_subpages',
              'redirect_when_logged_out', 'last_test_result', 'last_test_date']

    def get_changelist_form(self, request, **kwargs):
        kwargs.setdefault('form', AllinkLegacyChangeAdminForm)
        return super(AllinkLegacyLinkAdmin, self).get_changelist_form(request, **kwargs)

    def get_import_formats(self):
        """ We only allow csv for
            Google Analytics files
        """
        return [base_formats.CSV]

    def auto_test(self, request, queryset):
        for obj in queryset:
            obj.test_redirect(request)
    auto_test.short_description = 'Test redirect'

    def manual_test(self, obj):
        link = base_url() + obj.old
        return format_html('<a class="button" href="%s" target="_blank">Test</a>' % link)
    manual_test.short_description = 'Manual testing'

    def link_object(self, obj):
        return obj.link_object
    link_object.short_description = 'Page'


admin.site.register(AllinkLegacyLink, AllinkLegacyLinkAdmin)



# -*- coding: utf-8 -*-
import factory
from factory import fuzzy
from allink_core.core.test.factories import FilerImageFactory
from ..models import News, NewsAppContentPlugin


class NewsFactory(factory.DjangoModelFactory):

    class Meta:
        model = News

    title = factory.Sequence(lambda n: 'news entry %d' % n)
    # slug = ''
    lead = fuzzy.FuzzyText(length=500)
    preview_image = factory.SubFactory(FilerImageFactory)
    # template =
    # header_placeholder =
    # content_placeholder =


class NewsWithMetaFactory(NewsFactory):

    og_image = factory.SubFactory(FilerImageFactory)
    og_title = 'og title'
    og_description = 'og description'
    teaser_image = factory.SubFactory(FilerImageFactory)
    teaser_title = 'teaser title'
    teaser_technical_title = 'teaser technical title'
    teaser_description = 'teaser description'
    teaser_link_text = 'teaser link text'



# Generated by Django 2.2.9 on 2020-03-23 19:05

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('allink_image', '0002_auto_20191002_1951'),
    ]

    operations = [
        migrations.AlterField(
            model_name='allinkimageplugin',
            name='icon_enabled',
            field=models.BooleanField(blank=True, default=False, help_text='Show the icon that is used as long as the image is loading.<br><strong>Important:</strong> Disable this option if a transparent PNG image is used.', verbose_name='Loader Icon'),
        ),
    ]



# -*- coding: utf-8 -*-
from allink_core.core.views import AllinkBasePluginLoadMoreView, AllinkBaseDetailView
from allink_core.core.loading import get_model

News = get_model('news', 'News')
NewsAppContentPlugin = get_model('news', 'NewsAppContentPlugin')


class NewsPluginLoadMore(AllinkBasePluginLoadMoreView):
    model = News
    plugin_model = NewsAppContentPlugin


class NewsDetail(AllinkBaseDetailView):
    model = News



# Generated by Django 2.1.8 on 2019-07-02 17:18

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('cms', '0022_auto_20180620_1551'),
    ]

    operations = [
        migrations.CreateModel(
            name='AllinkInfoBoxPlugin',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, related_name='allink_info_box_allinkinfoboxplugin', serialize=False, to='cms.CMSPlugin')),
                ('counter', models.IntegerField(choices=[(0, 'Always visible'), (1, '1x'), (2, '2x'), (3, '3x'), (4, '4x'), (5, '5x')], default=0, help_text='After how many times/clicks should the box not be visible anymore', verbose_name='Display duration')),
                ('transparent_background', models.BooleanField(default=False, verbose_name='Transparent background')),
                ('template', models.CharField(help_text='Choose a template.', max_length=50, verbose_name='Template')),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin',),
        ),
    ]



# -*- coding: utf-8 -*-
from cms.toolbar_pool import toolbar_pool
from cms.toolbar_base import CMSToolbar

from allink_core.core.cms_toolbars import AllinkBaseModifierMixin
from allink_core.core.loading import get_model

News = get_model('news', 'News')


class NewsToolbar(AllinkBaseModifierMixin, CMSToolbar):
    model = News
    app_label = News._meta.app_label


toolbar_pool.register(NewsToolbar)



# -*- coding: utf-8 -*-
"""
use core:
from allink_core.apps.dummy_app.cms_plugins import *  # noqa
"""
from allink_core.apps.dummy_app.cms_plugins import *  # noqa

plugin_pool.unregister_plugin(CMSDummyAppAppContentPlugin)


@plugin_pool.register_plugin
class CMSDummyAppAppContentPlugin(CMSDummyAppAppContentPlugin):

    def render(self, context, instance, placeholder):
        context = super().render(context, instance, placeholder)

        context.update({
            'some': 'stuff',
        })

        return context



# -*- coding: utf-8 -*-
"""
use core:
from allink_core.apps.dummy_app.models import *  # noqa

if you overwrite, you don't have to override every model.
"""
from django.db import models
from parler.models import TranslatedField
from allink_core.apps.dummy_app.abstract_models import BaseDummyApp, BaseDummyAppTranslation, BaseDummyAppAppContentPlugin
from allink_core.core.loading import get_model


class DummyApp(BaseDummyApp):
    some_field = models.IntegerField(null=True)

    some_field_translated_field = TranslatedField(any_language=True)


class DummyAppTranslation(BaseDummyAppTranslation):
    some_field_translated_field = models.IntegerField(null=True)


class DummyAppAppContentPlugin(BaseDummyAppAppContentPlugin):
    data_model = get_model('dummy_app', 'DummyApp')
    some_plugin_field = models.IntegerField(null=True)


from allink_core.apps.dummy_app.models import *  # noqa



# -*- coding: utf-8 -*-
from django.core.exceptions import AppRegistryNotReady


class MandrillConfig:
    def __init__(self):
        from django.conf import settings
        from allink_core.core.loading import get_model

        try:
            config = get_model('config', 'Config').get_solo()
        except AppRegistryNotReady:
            config = None

        self.apikey = getattr(settings, 'MANDRILL_API_KEY')

        self.default_transactional_template_name = getattr(settings,
                                                           'MANDRILL_DEFAULT_TRANSACTIONAL_TEMPLATE', 'default')

        if settings.ALLINK_MANDRILL_DEV_MODE:
            # Testmode/ Development
            self.default_from_email = settings.ALLINK_MANDRILL_DEV_MODE_FROM_EMAIL_ADDRESS
            self.default_to_email = settings.ALLINK_MANDRILL_DEV_MODE_TO_EMAIL_ADDRESSES
        else:
            self.default_from_email = getattr(config, 'default_from_email',
                                              settings.ALLINK_MANDRILL_DEV_MODE_FROM_EMAIL_ADDRESS)
            self.default_to_email = getattr(config, 'default_to_email',
                                            settings.ALLINK_MANDRILL_DEV_MODE_TO_EMAIL_ADDRESSES)

    def get_default_from_name(self):
        from django.contrib.sites.models import Site
        return Site.objects.get_current().name

    def get_google_analytics_domains(self):
        from django.contrib.sites.models import Site
        return Site.objects.get_current().domain

    def get_site_domain(self):
        from django.contrib.sites.models import Site
        return Site.objects.get_current().domain



# -*- coding: utf-8 -*-

from django.db import models
from django.contrib.postgres.fields import ArrayField

from aldryn_translation_tools.models import TranslationHelperMixin

from parler import appsettings
from parler.managers import TranslatableManager, TranslatableQuerySet
from parler.models import TranslatableModel, TranslatedFields, TranslatableModelMixin
from parler.cache import _delete_cached_translations
from treebeard.ns_tree import NS_Node, NS_NodeManager, NS_NodeQuerySet

from allink_core.core.models.mixins import AllinkTranslatedAutoSlugifyMixin


LANGUAGE_CODES = appsettings.PARLER_LANGUAGES.get_active_choices()


class CategoryQuerySet(TranslatableQuerySet, NS_NodeQuerySet):
    pass


class CategoryManager(TranslatableManager, NS_NodeManager):
    queryset_class = CategoryQuerySet

    def get_queryset(self):
        return self.queryset_class(
            self.model,
            using=self._db
        ).order_by('tree_id', 'lft')

    def not_root(self, depth=100):
        return self.filter(depth__gte=depth)


class AllinkCategory(AllinkTranslatedAutoSlugifyMixin, TranslationHelperMixin,
                     TranslatableModel, NS_Node):
    """
      A category is hierarchical. The structure is implemented with django-
      treebeard's Nested Sets trees, which has the performance characteristics
      we're after, namely: fast reads at the expense of write-speed.
      """

    slug_source_field_name = 'name'

    model_names = ArrayField(models.CharField(
        max_length=50),
        help_text=('Please specify the app which uses this categories. '
                   'All apps specified in parent category are automatically added.'),
        blank=True,
        null=True
    )

    # used to decide if it should be possible to use
    # this category in a filter on a specific plugin.
    # all categories with the same tag can be used
    # in the same filter.
    tag = models.CharField(
        'Tag',
        max_length=80,
        help_text='auto-generated categories use this tag, to identify which app generated the category.',
        null=True,
        blank=True
    )

    # the verbose counterpart to field 'tag' (iidentifier can and has to be set manually)
    # as a addition to make queries on categories (for example to create filter slect dropdown in app plugins)
    identifier = models.CharField(
        'Identifier',
        max_length=50,
        help_text='Identifier used for backward reference on a app model. '
                  '(e.g display category name on People app, e.g Marketing)',
        blank=True,
        null=True
    )

    translations = TranslatedFields(
        name=models.CharField(
            'name',
            blank=False,
            default='',
            max_length=255,
        ),
        slug=models.SlugField(
            'slug',
            blank=True,
            default='',
            help_text=('Provide a “slug” or leave blank for an automatically '
                        'generated one.'),
            max_length=255,
        ),
        meta={'unique_together': [('language_code', 'slug')]},
    )

    objects = CategoryManager()

    class Meta:
        app_label = 'allink_categories'
        verbose_name = 'Category'
        verbose_name_plural = 'Categories'

    def __str__(self):
        return self.safe_translation_getter('name', any_language=True)

    def delete(self, using=None):
        #
        # We're simply managing how the two superclasses perform deletion
        # together here.
        #
        self.__class__.objects.filter(pk=self.pk).delete(using)
        _delete_cached_translations(self)
        super(TranslatableModelMixin, self).delete()



# -*- coding: utf-8 -*allink_core/core/models/base_plugins.py-
from allink_core.apps.news.abstract_models import (
    BaseNews,
    BaseNewsTranslation,
    BaseNewsAppContentPlugin,
)
from allink_core.core.loading import get_model
from allink_core.core.loading import is_model_registered

__all__ = []

if not is_model_registered('news', 'News'):
    class News(BaseNews):
        pass

    __all__.append('News')

if not is_model_registered('news', 'NewsTranslation'):
    class NewsTranslation(BaseNewsTranslation):
        pass

    __all__.append('NewsTranslation')

if not is_model_registered('news', 'NewsAppContentPlugin'):
    class NewsAppContentPlugin(BaseNewsAppContentPlugin):
        data_model = get_model('news', 'News')

    __all__.append('NewsAppContentPlugin')



# -*- coding: utf-8 -*-
from menus.base import NavigationNode
from menus.menu_pool import menu_pool
from cms.menu_bases import CMSAttachMenu

from allink_core.core.loading import get_model, get_class


People = get_model('people', 'People')


class PeopleMenu(CMSAttachMenu):

    name = "People menu"

    def get_nodes(self, request):

        nodes = []
        for entry in People.objects.active():
            node = NavigationNode(
                entry.title,
                entry.get_absolute_url(),
                entry.sort_order,
                attr={
                    'description': entry.lead
                })
            nodes.append(node)

        return nodes


menu_pool.register_menu(get_class('people.cms_menus', 'PeopleMenu'))



# -*- coding: utf-8 -*-
from django.db import models
from django.contrib.postgres.fields import ArrayField
from djangocms_attributes_field.fields import AttributesField
from cms.models.pluginmodel import CMSPlugin
from filer.fields.image import FilerImageField
from filer.fields.file import FilerFileField

from allink_core.core.models.choices import VIDEO_SERVICE_CHOICES
from allink_core.core.models.fields import CMSPluginField


class AllinkVideoBasePlugin(CMSPlugin):
    attributes = AttributesField(
        verbose_name='Attributes',
        blank=True,
    )

    project_css_classes = ArrayField(
        models.CharField(
            max_length=50,
            blank=True,
            null=True
        ),
        blank=True,
        null=True
    )

    cmsplugin_ptr = CMSPluginField()

    class Meta:
        abstract = True

    def __str__(self):
        return self.video_id or self.video_service

    @property
    def css_classes(self):
        css_classes = []
        if getattr(self, 'project_css_classes'):
            for css_class in getattr(self, 'project_css_classes'):
                css_classes.append(css_class)
        return ' '.join(css_classes)


class AllinkVideoEmbedPlugin(AllinkVideoBasePlugin):
    """
    Renders an Iframe when ``link``
    """

    video_id = models.CharField(
        verbose_name='Video ID',
        max_length=255,
        help_text=('Only provide the ID. The correct URL will automatically be generated.<br><br>'
                   'YouTube: https://www.youtube.com/watch?v=<strong>12345678</strong> '
                   '(the ID is <strong>12345678</strong>)<br>Vimeo: https://vimeo.com/<strong>12345678</strong> '
                   '(the ID is <strong>12345678</strong>)'),
    )
    video_service = models.CharField(
        'Video Service',
        max_length=50,
        choices=VIDEO_SERVICE_CHOICES,
    )
    ratio = models.CharField(
        'Ratio',
        max_length=50,
        blank=True,
        null=True
    )
    auto_start_enabled = models.BooleanField(
        'Autostart',
        default=False,
        help_text='<strong>Important:</strong> Autoplaying videos with audio is not recommended. Use wisely. ',
    )
    allow_fullscreen_enabled = models.BooleanField(
        'Allow fullscreen',
        default=True
    )

    class Meta:
        verbose_name = 'Allink Video Embed'

    def __str__(self):
        return self.video_id or self.video_service


class AllinkVideoFilePlugin(AllinkVideoBasePlugin):
    """
    writes HTML5 <video> tag for video_file
    """

    video_file = FilerFileField(
        verbose_name='Video File',
        on_delete=models.PROTECT,
        help_text=('Recommended video settings:<br><br>Format: mp4<br>Codec: H.264<br>Target Bitrate: 2 '
                   '(video loads quick and runs smooth)<br>Audio: Not recommended '
                   '(no audio = smaller file size and less annoyed visitors)<br>File size: '
                   'Dependent of video length. Generally speaking: Less is more.'),
        null=True,
        related_name='%(app_label)s_%(class)s_video_file',
    )
    video_poster_image = FilerImageField(
        verbose_name='Video Start Image',
        on_delete=models.PROTECT,
        related_name='%(app_label)s_%(class)s_video_poster_image',
        help_text=(
            'Image that is being displayed while the video is loading. '
            'Ideally the very first frame of the video is used, in order to make the transition as smooth as '
            'possible.<br><br><strong>Imoprtant:</strong> Make sure the aspect ratio of the image is '
            '<strong>exactly the same</strong> as the video, otherwise the video height will shrink or grow when the '
            'playback starts.'),
        null=True
    )
    video_file_width = models.IntegerField(
        'Video width',
        blank=True,
        null=True,
    )
    video_file_height = models.IntegerField(
        'Video height',
        blank=True,
        null=True,
    )
    video_muted_enabled = models.BooleanField(
        'Muted',
        help_text='Caution: Autoplaying videos with audio is not recommended. Use wisely.',
        default=True
    )
    poster_only_on_mobile = models.BooleanField(
        'Image Only (Mobile)',
        help_text='Disable video on mobile devices and only show the start image without video control.',
        default=True
    )
    auto_start_enabled = models.BooleanField(
        'Autostart',
        default=True
    )
    auto_start_mobile_enabled = models.BooleanField(
        'Autostart mobile',
        default=False,
        help_text='Caution: Autoplaying videos on mobile is not recommended. Use wisely.',
    )
    allow_fullscreen_enabled = models.BooleanField(
        'Allow fullscreen',
        default=False
    )

    class Meta:
        verbose_name = 'Allink Video File'

    def __str__(self):
        return self.video_file.name

    def copy_relations(self, oldinstance):
        self.video_poster_image = oldinstance.video_poster_image

    # TODO not working yet on stage and production
    # def get_video_dimensions(self):
    #     import subprocess
    #     import shlex
    #     import json
    #
    #     cmd = "avprobe -show_streams -of json"
    #     args = shlex.split(cmd)
    #     args.append(self.video_file.file.path)
    #     avprobeOutput = subprocess.check_output(args).decode('utf-8')
    #     avprobeOutput = json.loads(avprobeOutput)
    #
    #     # find height and width
    #     width = avprobeOutput['streams'][0]['width']
    #     height = avprobeOutput['streams'][0]['height']
    #
    #     return width, height

    # def save(self, no_signals=False, *args, **kwargs):
    # self.video_file_width, self.video_file_height = self.get_video_dimensions()
    # super(AllinkVideoFilePlugin, self).save(*args, **kwargs)



# -*- coding: utf-8 -*-
from django import forms
from django.contrib import admin
from django.shortcuts import redirect
from django.urls import path
from django.core.cache import cache

from cms.admin.pageadmin import PageAdmin
from cms.admin.forms import ChangePageForm, AddPageForm
from cms.models.pagemodel import Page
from cms.extensions import PageExtensionAdmin, TitleExtensionAdmin

from solo.admin import SingletonModelAdmin
from webpack_loader.utils import get_files
from parler.admin import TranslatableAdmin
from parler.forms import TranslatableModelForm

from allink_core.core.loading import get_model
from allink_core.core.forms.fields import ColorField
from allink_core.core.utils import get_project_color_choices
from allink_core.core.admin.mixins import AllinkMediaAdminMixin

Config = get_model('config', 'Config')
AllinkPageExtension = get_model('config', 'AllinkPageExtension')
AllinkTitleExtension = get_model('config', 'AllinkTitleExtension')


class ConfigAdminForm(TranslatableModelForm):
    theme_color = ColorField(label='Theme Color', help_text='Theme color for Android Chrome', required=False)
    mask_icon_color = ColorField(label='Mask Icon Color',
                                 help_text='Mask icon color for safari-pinned-tab.svg', required=False)
    msapplication_tilecolor = ColorField(label='MS Application Title Color',
                                         help_text='MS application TitleColor Field', required=False)

    class Meta(forms.ModelForm):
        model = Config
        exclude = ()


@admin.register(Config)
class ConfigAdmin(AllinkMediaAdminMixin, TranslatableAdmin, SingletonModelAdmin):
    form = ConfigAdminForm
    change_form_template = 'config/admin/change_form.html'

    def get_fieldsets(self, request, obj=None):

        if get_project_color_choices():
            fieldsets = ('Site Meta', {
                'classes': (
                    'collapse',
                ),
                'fields': (
                    'default_og_image',
                    'default_base_title',
                    'theme_color',
                    'mask_icon_color',
                    'msapplication_tilecolor',
                    'google_site_verification',
                )
            }),
        else:
            fieldsets = ('Site Meta', {
                'classes': (
                    'collapse',
                ),
                'fields': (
                    'default_og_image',
                    'default_base_title',
                    'google_site_verification',
                )
            }),

        fieldsets += ('Email', {
            'classes': (
                'collapse',
            ),
            'fields': (
                'default_to_email',
                'default_from_email',
            )
        }),

        fieldsets += ('Newsletter Signup', {
            'classes': (
                'collapse',
            ),
            'fields': (
                'newsletter_lead',
                'newsletter_signup_link',
                'newsletter_teaser_counter',
                'newsletter_declaration_of_consent',
            )
        }),

        return fieldsets

    def clearcache(self, request, object_id):
        cache.clear()
        info = self.model._meta.app_label, self.model._meta.model_name
        return redirect('admin:%s_%s_changelist' % info)

    def get_urls(self):
        urls = super(ConfigAdmin, self).get_urls()
        info = self.model._meta.app_label, self.model._meta.model_name
        my_urls = [
            path('clearcache/<int:object_id>/',
                 self.admin_site.admin_view(self.clearcache),
                 name='%s_%s_clearcache' % info
                 )
        ]
        return my_urls + urls


@admin.register(AllinkPageExtension)
class AllinkPageExtensionAdmin(PageExtensionAdmin):
    fieldsets = (
        ('Teaser', {
            'fields': (
                'teaser_image',
            )
        }),
        ('SEO', {
            'classes': ('collapse',),
            'fields': (
                'og_image',
            )
        }),
    )


@admin.register(AllinkTitleExtension)
class AllinkTitleExtensionAdmin(TitleExtensionAdmin):
    fieldsets = (
        ('Teaser', {
            'fields': (
                'teaser_title',
                'teaser_technical_title',
                'teaser_description',
                'teaser_link_text',
            )
        }),
        ('SEO', {
            'classes': ('collapse',),
            'fields': (
                'og_title',
                'og_description',
            )
        }),
    )


"""
We use our own meta fields on the AllinkPageExtension and AllinkTitleExtension models.
So therefore we hide the page_title and the meta_description on the page admin, to reduce confusion.
"""


class AllinkChangePageForm(ChangePageForm):
    page_title = forms.CharField(widget=forms.HiddenInput(), required=False)
    meta_description = forms.CharField(widget=forms.HiddenInput(), required=False)
    menu_title = forms.CharField(widget=forms.HiddenInput(), required=False)


class AllinkAddPageForm(AddPageForm):
    page_title = forms.CharField(widget=forms.HiddenInput(), required=False)
    meta_description = forms.CharField(widget=forms.HiddenInput(), required=False)
    menu_title = forms.CharField(widget=forms.HiddenInput(), required=False)


PageAdmin.form = AllinkAddPageForm
PageAdmin.add_form = AllinkAddPageForm
PageAdmin.change_form = AllinkChangePageForm


admin.site.unregister(Page)
admin.site.register(Page, PageAdmin)



# -*- coding: utf-8 -*-
"""
use core:
from allink_core.apps.dummy_app.cms_menus import *  # noqa
"""
from allink_core.core.loading import unregister_cms_menu
from allink_core.apps.dummy_app.cms_menus import *  # noqa

unregister_cms_menu(DummyAppMenu)


class DummyAppMenu(DummyAppMenu):
    pass


menu_pool.register_menu(get_class('dummy_app.cms_menus', 'DummyAppMenu'))



# Generated by Django 2.1.10 on 2019-07-16 09:51

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('allink_teaser', '0002_auto_20190703_1528'),
    ]

    operations = [
        migrations.AlterField(
            model_name='allinkteaserplugin',
            name='teaser_description',
            field=models.TextField(blank=True, default='', help_text='Page: no fallback.<br>App: fallback is field "lead".Please only use 80 to 120 characters. Best results will be achieved with around 100 characters.', verbose_name='Teaser description'),
        ),
    ]



# -*- coding: utf-8 -*-

from allink_core.core.loading import get_model
from allink_core.core.sitemap import HrefLangSitemap


Locations = get_model('locations', 'Locations')


class LocationsSitemap(HrefLangSitemap):

    changefreq = "never"
    priority = 0.5
    i18n = True

    def __init__(self, *args, **kwargs):
        self.namespace = kwargs.pop('namespace', None)
        super(LocationsSitemap, self).__init__(*args, **kwargs)

    def items(self):
        return Locations.objects.translated()

    def lastmod(self, obj):
        return obj.modified



# -*- coding: utf-8 -*-
from cms.toolbar_pool import toolbar_pool
from cms.toolbar_base import CMSToolbar

from allink_core.core.cms_toolbars import AllinkBaseModifierMixin
from allink_core.core.loading import get_model

Config = get_model('config', 'Config')
People = get_model('people', 'People')


class PeopleToolbar(AllinkBaseModifierMixin, CMSToolbar):
    model = People
    app_label = People._meta.app_label


toolbar_pool.register(PeopleToolbar)



# # -*- coding: utf-8 -*-
from django.urls import path
from .views import DummyAppPluginLoadMore, DummyAppDetail


urlpatterns = [
    path('<int:page>/', DummyAppPluginLoadMore.as_view(), name='more'),
    path('<slug:slug>/', DummyAppDetail.as_view(), name='detail'),
]



# -*- coding: utf-8 -*-
from django.utils.translation import ugettext_lazy as _
from django.db import models

from cms.models.fields import PageField
from cms.models.fields import PlaceholderField
from adminsortable.models import SortableMixin
from parler.models import TranslatedField
from djangocms_text_ckeditor.fields import HTMLField
from filer.fields.image import FilerImageField
from django.utils.functional import cached_property

from allink_core.core.models.fields import SortedM2MModelField
from allink_core.core.models import (
    AllinkCategoryFieldsModel,
    AllinkBaseTranslatableModel,
    AllinkBaseAppContentPlugin,
    AllinkContactFieldsModel,
    AllinkAddressFieldsModel,
    AllinkBaseTranslatedFieldsModel,
)
from allink_core.core.models.choices import SALUTATION_CHOICES
from allink_core.core.loading import get_class


AllinkPeopleManager = get_class('people.managers', 'AllinkPeopleManager')


class BasePeople(SortableMixin, AllinkContactFieldsModel, AllinkAddressFieldsModel,
                 AllinkCategoryFieldsModel, AllinkBaseTranslatableModel):
    slug_source_field_name = 'full_name'

    salutation = models.IntegerField(
        _('Salutation'),
        choices=SALUTATION_CHOICES,
        null=True
    )
    first_name = models.CharField(
        _('First Name'),
        max_length=255
    )
    last_name = models.CharField(
        _('Last Name'),
        max_length=255
    )
    lead = TranslatedField()
    company_name = models.CharField(
        _('Company Name'),
        max_length=255,
        blank=True,
        null=True
    )
    preview_image = FilerImageField(
        verbose_name='Preview Image',
        blank=True,
        null=True,
        on_delete=models.PROTECT,
        related_name='%(app_label)s_%(class)s_preview_image',
    )
    sort_order = models.PositiveIntegerField(
        default=0,
        editable=False,
        db_index=True
    )
    header_placeholder = PlaceholderField(
        'people_header',
        related_name='%(app_label)s_%(class)s_header_placeholder'
    )
    content_placeholder = PlaceholderField(
        'people_content',
        related_name='%(app_label)s_%(class)s_content_placeholder'
    )

    objects = AllinkPeopleManager()

    class Meta:
        abstract = True
        app_label = 'people'
        ordering = 'sort_order',
        verbose_name = 'Person'
        verbose_name_plural = 'People'

    def __str__(self):
        return '%s - %s' % (self.full_name, self.created.strftime('%d.%m.%Y'))

    @cached_property
    def full_name(self):
        return '{} {}'.format(self.first_name, self.last_name)

    @cached_property
    def title(self):
        return '{} {}'.format(self.first_name, self.last_name)

    @cached_property
    def units(self):
        units = []
        for unit in self.categories.filter(identifier='units'):
            units.append(unit.name)
        return ','.join(units)


class BasePeopleTranslation(AllinkBaseTranslatedFieldsModel):
    master = models.ForeignKey(
        'people.People',
        on_delete=models.CASCADE,
        related_name='translations',
        null=True
    )
    job_function = models.CharField(
        'Function',
        max_length=255,
        blank=True,
        null=True,
    )
    lead = HTMLField(
        'Lead Text',
        help_text=('Teaser text that in some cases is used in the list view '
                   'and/or in the detail view.'),
        blank=True,
        null=True,
    )

    class Meta:
        abstract = True
        app_label = 'people'


class BasePeopleAppContentPlugin(AllinkBaseAppContentPlugin):
    manual_entries = SortedM2MModelField(
        'people.People',
        blank=True,
        help_text=('Select and arrange specific entries, or, leave blank to select all. (If '
                   'manual entries are selected the category filtering will be applied as well.)')
    )
    apphook_page = PageField(
        verbose_name='Apphook Page',
        null=True,
        blank=True,
        on_delete=models.PROTECT,
        help_text='If provided, this Apphook-Page will be used to generate the detail link.',
    )

    class Meta:
        abstract = True
        app_label = 'people'

    def save(self, *args, **kwargs):
        super(BasePeopleAppContentPlugin, self).save(*args, **kwargs)



try:
    from celery import shared_task

    @shared_task
    def send_transactional_mail_celery(template_name, message, template_content):
        """
        task for Mandrill Base class to enable full async sending of messages
        """
        import mandrill
        from .config import MandrillConfig
        config = MandrillConfig()
        mandrill_client = mandrill.Mandrill(config.apikey)
        result = mandrill_client.messages.send_template(template_name=template_name,
                                                        template_content=template_content, message=message,
                                                        async=False)
        return result[0].get('status'), result[0].get('reject_reason')
except ImportError:
    pass  # If celery is not there we can't send it with it...



# -*- coding: utf-8 -*-
from allink_core.core.views import AllinkBasePluginLoadMoreView, AllinkBaseDetailView
from .models import DummyApp, DummyAppAppContentPlugin


class DummyAppPluginLoadMore(AllinkBasePluginLoadMoreView):
    model = DummyApp
    plugin_model = DummyAppAppContentPlugin


class DummyAppDetail(AllinkBaseDetailView):
    model = DummyApp



# -*- coding:utf-8 -*-
from __future__ import unicode_literals
from django import template

register = template.Library()


@register.filter('in_one_group')
def in_one_group(user, groups=None):
    """
    Checks if user is at least in one of the provided groups
    """
    return True if any(map(lambda each: each in groups, user.groups.all())) else False



# -*- coding: utf-8 -*-

from __future__ import unicode_literals

from django.test import TestCase

from allink_core.core_apps.allink_categories.tests import CategoryTestCaseMixin
from allink_core.core_apps.allink_categories.models import AllinkCategory as Category


class AdminTest(CategoryTestCaseMixin, TestCase):

    def test_admin_owner_default(self):
        """
        Test that the ChangeForm contains Treebeard's MoveNodeForm
        """
        from django.contrib import admin
        admin.autodiscover()

        user = self.create_user()
        user.is_superuser = True
        user.save()

        root = Category.add_root(name="test root")
        root.save()
        root = self.reload(root)
        root.add_child(name="test child 1")
        root.add_child(name="test child 2")

        admin_inst = admin.site._registry[Category]

        request = self.get_request('en')
        request.user = user
        request.META['HTTP_HOST'] = 'example.com'
        response = admin_inst.add_view(request)
        option = '<option value="first-child">First child of</option>'
        self.assertContains(response, option)



# -*- coding: utf-8 -*-
from allink_core.core.models.managers import AllinkCategoryModelQuerySet


class DummyAppQuerySet(AllinkCategoryModelQuerySet):
    pass


DummyAppManager = DummyAppQuerySet.as_manager



# Generated by Django 2.1.11 on 2019-10-17 09:36

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('allink_video', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='allinkvideofileplugin',
            name='auto_start_mobile_enabled',
            field=models.BooleanField(default=False, help_text='Caution: Autoplaying videos on mobile is not recommended. Use wisely.', verbose_name='Autostart mobile'),
        ),
    ]



import os.path
import tempfile
from allink_core.core.allink_settings import *  # noqa
from allink_core import get_core_apps, ALLINK_CORE_MAIN_TEMPLATE_DIRS
from django.utils.translation import ugettext_lazy as _

BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(os.path.abspath(__file__))))
TEST_DIR = os.path.dirname(os.path.abspath(os.path.abspath(__file__)))

SITE_ID = 1
ROOT_URLCONF = 'test.urls'
STAGE = 'local'

SECRET_KEY = 'not-very-random'

STATIC_URL = '/static/'
STATIC_ROOT = os.path.join(BASE_DIR, 'static_collected')
STATICFILES_DIRS = [os.path.join(BASE_DIR, 'static')]

MEDIA_ROOT = tempfile.TemporaryDirectory(prefix='media_test').name
TIME_ZONE = 'Europe/Zurich'

USE_L10N = True
USE_I18N = True

LANGUAGE_CODE = 'en'

LANGUAGES = (
    ('en', 'English'),
    ('de', 'German'),
    ('fr', 'French'),
)

CMS_LANGUAGES = {
    1: [
        {
            'code': 'en',
            'name': 'English',
            'fallbacks': ['de', 'fr', ]
        },
        {
            'code': 'de',
            'name': 'Deutsche',
            'fallbacks': ['en', ]  # FOR TESTING DO NOT ADD 'fr' HERE
        },
        {
            'code': 'fr',
            'name': 'Française',
            'fallbacks': ['en', ]  # FOR TESTING DO NOT ADD 'de' HERE
        },
        {
            'code': 'it',
            'name': 'Italiano',
            'fallbacks': ['fr', ]  # FOR TESTING, LEAVE AS ONLY 'fr'
        },
    ],
    'default': {
        'redirect_on_fallback': True,  # PLEASE DO NOT CHANGE THIS
    }
}

PARLER_LANGUAGES = {
    1: [
        {
            'code': 'en',
            'fallbacks': ['de', ],
        },
        {
            'code': 'de',
            'fallbacks': ['en', ],
        },
    ],
    'default': {
        'code': 'en',
        'fallbacks': ['en'],
        'hide_untranslated': False
    }
}

DATABASES = {
    'default': {
        'NAME': 'db',
        'USER': 'postgres',
        'PASSWORD': '',
        'HOST': 'localhost',
        'PORT': 5432,
        'CONN_MAX_AGE': 0,
        'ENGINE': 'django.db.backends.postgresql_psycopg2',
        'ATOMIC_REQUESTS': False,
        'AUTOCOMMIT': True,
        'OPTIONS': {},
        'TIME_ZONE': None,
        'TEST': {'CHARSET': None, 'COLLATION': None, 'NAME': None, 'MIRROR': None}
    }
}

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [os.path.join(BASE_DIR, 'templates'),
                 os.path.join(BASE_DIR, 'allink_core/core/templates/allink_core/')],
        'OPTIONS':
            {'debug': True,
             'context_processors': [
                 'django.contrib.auth.context_processors.auth',
                 'django.contrib.messages.context_processors.messages',
                 'django.template.context_processors.i18n',
                 'django.template.context_processors.debug',
                 'django.template.context_processors.request',
                 'django.template.context_processors.media',
                 'django.template.context_processors.csrf',
                 'django.template.context_processors.tz',
                 'django.template.context_processors.static',
                 # 'aldryn_django.context_processors.debug',
                 'sekizai.context_processors.sekizai',
                 'cms.context_processors.cms_settings',
                 # 'aldryn_boilerplates.context_processors.boilerplate',
                 # 'aldryn_snake.template_api.template_processor',
                 'django.template.context_processors.request'
             ],
             'loaders': [
                 'django.template.loaders.filesystem.Loader',
                 # 'aldryn_boilerplates.template_loaders.AppDirectoriesLoader',
                 'django.template.loaders.app_directories.Loader'
             ]
             }
    }
]

MIDDLEWARE = [
    'django.middleware.cache.UpdateCacheMiddleware',
    'cms.middleware.utils.ApphookReloadMiddleware',
    'django.middleware.gzip.GZipMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.locale.LocaleMiddleware',
    'django.contrib.sites.middleware.CurrentSiteMiddleware',
    # 'aldryn_sites.middleware.SiteMiddleware',
    'django.middleware.security.SecurityMiddleware',
    'django.middleware.common.CommonMiddleware',
    'cms.middleware.user.CurrentUserMiddleware',
    'cms.middleware.page.CurrentPageMiddleware',
    'cms.middleware.toolbar.ToolbarMiddleware',
    'cms.middleware.language.LanguageCookieMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
    # 'lockdown.middleware.LockdownMiddleware',
    # 'allink_core.core.middleware.AllinkUrlRedirectMiddleware',
    'allink_core.core_apps.allink_legacy_redirect.middleware.AllinkLegacyRedirectMiddleware',
    'debug_toolbar.middleware.DebugToolbarMiddleware',
    'django.middleware.cache.FetchFromCacheMiddleware'
]

CACHES = {
    'default': {
        'BACKEND': 'django.core.cache.backends.dummy.DummyCache'
    }
}

INSTALLED_APPS = [
    # 'aldryn_addons',
    # 'aldryn_django',
    # 'aldryn_sso',
    # 'aldryn_django_cms',
    'djangocms_admin_style',
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.sites',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'cms',
    'menus',
    'sekizai',
    'treebeard',
    'parler',
    'robots',
    'djangocms_text_ckeditor',
    'filer',
    'easy_thumbnails',
    'mptt',
    'aldryn_google_tag_manager'] + ALLINK_INSTALLED_APPS

# allink apps which are installed in this project
INSTALLED_ALLINK_CORE_APPS = [
    'allink_core.apps.config',
    # 'allink_core.apps.locations',
    'allink_core.apps.news',
    # 'allink_core.apps.people',
    # 'allink_core.apps.testimonials',
]
# allink apps which are overriden in this project
OVERRIDDEN_ALLINK_CORE_APPS = [
    # 'allink_apps.locations',
    # 'allink_apps.news',
    # 'allink_apps.people',
    # 'allink_apps.testimonials',
]
INSTALLED_APPS.extend(get_core_apps(OVERRIDDEN_ALLINK_CORE_APPS, INSTALLED_ALLINK_CORE_APPS))

LOCALE_PATHS = ALLINK_LOCALE_PATHS

CMS_PERMISSION = True
CMS_TEMPLATES = (
    ('default.html', 'Default'),
)

PROJECT_APP_MODEL_WITH_CATEGORY_CHOICES = ALLINK_PROJECT_APP_MODEL_WITH_CATEGORY_CHOICES

NEWS_PLUGIN_TEMPLATES = (
    ('grid_static', 'Grid (Static)'),
)

TEASER_PAGE_LINK_TEXT = _('Read more')

THUMBNAIL_WIDTH_ALIASES = {
    # used for plugins e.g. image, gallery>image
    '1-of-1': {
        'xs': {'width': 450, 'ratio': '3-2'},
        'sm': {'width': 1200, 'ratio': '3-2'},
        'xl': {'width': 1500, 'ratio': '3-2'}
    },
    '1-of-2': {
        'xs': {'width': 450, 'ratio': '3-2'},
        'sm': {'width': 650, 'ratio': '3-2'},
        'xl': {'width': 900, 'ratio': '3-2'}
    },
    '2-of-3': {
        'xs': {'width': 450, 'ratio': '3-2'},
        'sm': {'width': 600, 'ratio': '3-2'},
        'xl': {'width': 800, 'ratio': '3-2'}
    },
    '1-of-3': {
        'xs': {'width': 450, 'ratio': '3-2'},
        'sm': {'width': 400, 'ratio': '3-2'},
        'xl': {'width': 400, 'ratio': '3-2'}
    },
    '1-of-4': {
        'xs': {'width': 450, 'ratio': '3-2'},
        'sm': {'width': 500, 'ratio': '3-2'},
        'xl': {'width': 500, 'ratio': '3-2'}
    },
    'test-original': {
        'xs': {'width': 450, 'ratio': 'x-y'},
        'sm': {'width': 500, 'ratio': 'x-y'},
        'xl': {'width': 500, 'ratio': 'x-y'}
    },
}

WEBPACK_LOADER = {
    'DEFAULT': {
        'CACHE': False,
        'BUNDLE_DIR_NAME': 'webpack_bundles/',  # must end with slash
        'STATS_FILE': os.path.join(TEST_DIR, 'webpack-stats.json'),
        'POLL_INTERVAL': 0.1,
        'TIMEOUT': None,
        'IGNORE': [r'.+\.hot-update.js', r'.+\.map']
    }
}

SOLO_CACHE_TIMEOUT = 60 * 60 * 24 * 180


# -*- coding: utf-8 -*-
import os
from django.test import TestCase
from django.test.client import RequestFactory
from django.template.loader import render_to_string

from cms.api import add_plugin
from cms.models import Placeholder
from cms.plugin_rendering import ContentRenderer

import allink_core.core_apps.allink_social_icon as app
from allink_core.core_apps.allink_social_icon.cms_plugins import CMSAllinkSocialIconContainerPlugin, CMSAllinkSocialIconPlugin

APP_NAME = 'allink_social_icon'
TEMPLATE_DIR = os.path.join(os.path.dirname(app.__file__), 'templates', APP_NAME)


class CMSAllinkSocialIconContainerPluginTest(TestCase):

    def test_plugin_html(self):
        placeholder = Placeholder.objects.create(slot='test')
        model_instance = add_plugin(
            placeholder,
            CMSAllinkSocialIconContainerPlugin,
            'en',
        )
        renderer = ContentRenderer(request=RequestFactory())
        html = renderer.render_plugin(model_instance, {})
        self.assertEqual(html, render_to_string(os.path.join(TEMPLATE_DIR, 'content.html')))


class CMSAllinkSocialIconPluginTest(TestCase):

    def test_plugin_html(self):
        placeholder = Placeholder.objects.create(slot='test')
        model_instance = add_plugin(
            placeholder,
            CMSAllinkSocialIconPlugin,
            'en',
        )
        renderer = ContentRenderer(request=RequestFactory())
        html = renderer.render_plugin(model_instance, {})
        self.assertEqual(html, render_to_string(os.path.join(TEMPLATE_DIR, 'item.html')))



# -*- coding: utf-8 -*-

from django.contrib.admin.templatetags.admin_modify import *
from django.contrib.admin.templatetags.admin_modify import submit_row as original_submit_row


@register.inclusion_tag('admin/submit_line.html', takes_context=True)
def submit_row(context):
    ctx = original_submit_row(context)
    ctx.update({
        'show_save': context.get('show_save', True),
        'hide_save_and_add_another': context.get('hide_save_and_add_another'),
        'hide_save_and_continue': context.get('hide_save_and_continue')
    })

    return ctx



# -*- coding: utf-8 -*-
import re

# Stop Words courtesy of:
# http://www.dcs.gla.ac.uk/idom/ir_resources/linguistic_utils/stop_words
STOP_WORDS = r"""\b(a|about|above|across|after|afterwards|again|against|all|
almost|alone|along|already|also|although|always|am|among|amongst|amoungst|
amount|an|and|another|any|anyhow|anyone|anything|anyway|anywhere|are|around|as|
at|back|be|became|because|become|becomes|becoming|been|before|beforehand|
behind|being|below|beside|besides|between|beyond|bill|both|bottom|but|by|call|
can|cannot|cant|co|computer|con|could|couldnt|cry|de|describe|detail|do|done|
down|due|during|each|eg|eight|either|eleven|else|elsewhere|empty|enough|etc|
even|ever|every|everyone|everything|everywhere|except|few|fifteen|fify|fill|
find|fire|first|five|for|former|formerly|forty|found|four|from|front|full|
further|get|give|go|had|has|hasnt|have|he|hence|her|here|hereafter|hereby|
herein|hereupon|hers|herself|him|himself|his|how|however|hundred|i|ie|if|in|
inc|indeed|interest|into|is|it|its|itself|keep|last|latter|latterly|least|less|
ltd|made|many|may|me|meanwhile|might|mill|mine|more|moreover|most|mostly|move|
much|must|my|myself|name|namely|neither|never|nevertheless|next|nine|no|nobody|
none|noone|nor|not|nothing|now|nowhere|of|off|often|on|once|one|only|onto|or|
other|others|otherwise|our|ours|ourselves|out|over|own|part|per|perhaps|please|
put|rather|re|same|see|seem|seemed|seeming|seems|serious|several|she|should|
show|side|since|sincere|six|sixty|so|some|somehow|someone|something|sometime|
sometimes|somewhere|still|such|system|take|ten|than|that|the|their|them|
themselves|then|thence|there|thereafter|thereby|therefore|therein|thereupon|
these|they|thick|thin|third|this|those|though|three|through|throughout|thru|
thus|to|together|too|top|toward|towards|twelve|twenty|two|un|under|until|up|
upon|us|very|via|was|we|well|were|what|whatever|when|whence|whenever|where|
whereafter|whereas|whereby|wherein|whereupon|wherever|whether|which|while|
whither|who|whoever|whole|whom|whose|why|will|with|within|without|would|yet|
you|your|yours|yourself|yourselves)\b"""

STOP_WORDS_RE = re.compile(STOP_WORDS, re.IGNORECASE)



# -*- coding: utf-8 -*-
from django.db import models
from django.utils.translation import ugettext
from django.contrib.postgres.fields import ArrayField

from djangocms_attributes_field.fields import AttributesField
from cms.models.pluginmodel import CMSPlugin
from filer.fields.image import FilerImageField

from allink_core.core.models import AllinkLinkFieldsModel
from allink_core.core.models.fields import CMSPluginField


class AllinkImagePlugin(AllinkLinkFieldsModel, CMSPlugin):
    """
     Renders an image with the option of adding a link
    """

    picture = FilerImageField(
        verbose_name='Image',
        null=True,
        on_delete=models.PROTECT,
        related_name='%(app_label)s_%(class)s_picture',
    )
    ratio = models.CharField(
        'Ratio',
        max_length=50,
        blank=True,
        null=True
    )
    bg_enabled = models.BooleanField(
        verbose_name='Placeholder Background Color',
        blank=True,
        default=True,
        help_text=('Show default image placeholder background color.<br><strong>Important:</strong> '
                   'Disabling this option results in a transparent background even if a specific color is set '
                   '(this makes sense when a transparent PNG image is used)'),
    )
    icon_enabled = models.BooleanField(
        verbose_name='Loader Icon',
        blank=True,
        default=False,
        help_text=('Show the icon that is used as long as the image is loading.<br>'
                   '<strong>Important:</strong> Disable this option if a transparent PNG image is used.'),
    )
    bg_color = models.CharField(
        'Set a predefined background color',
        max_length=50,
        blank=True,
        null=True
    )
    caption_text = models.TextField(
        verbose_name='Caption text',
        blank=True,
        help_text='Provide a description, attribution, copyright or other information.'
    )
    attributes = AttributesField(
        verbose_name='Attributes',
        blank=True,
        excluded_keys=['src', 'width', 'height'],
    )
    project_css_classes = ArrayField(
        models.CharField(
            max_length=50,
            blank=True,
            null=True
        ),
        blank=True,
        null=True
    )
    width_alias = models.CharField(
        'Width Alias',
        max_length=50,
        blank=True,
        null=True
    )

    cmsplugin_ptr = CMSPluginField()

    def __str__(self):
        if self.picture and self.picture.label:
            return self.picture.label
        return str(self.pk)

    def save(self, *args, **kwargs):
        super(AllinkImagePlugin, self).save(*args, **kwargs)

    @property
    def css_classes(self):
        css_classes = []
        css_classes.append("has-bg-color") if self.bg_color else None
        css_classes.append(self.bg_color) if self.bg_color else None
        if getattr(self, 'project_css_classes'):
            for css_class in getattr(self, 'project_css_classes'):
                css_classes.append(css_class)
        return ' '.join(css_classes)

    def get_short_description(self):
        if self.picture and self.picture.label:
            return self.picture.label
        return ugettext('<file is missing>')

    def copy_relations(self, oldinstance):
        self.picture = oldinstance.picture



# -*- coding: utf-8 -*-
from django.contrib import admin, messages
from adminsortable.admin import SortableAdmin
from allink_core.core.loading import get_model
from parler.admin import TranslatableAdmin
from allink_core.core.admin import AllinkMediaAdminMixin, AllinkSEOAdminMixin, \
    AllinkCategoryAdminMixin, AllinkTeaserAdminMixin

Locations = get_model('locations', 'Locations')


@admin.register(Locations)
class LocationsAdmin(AllinkMediaAdminMixin, AllinkSEOAdminMixin, AllinkCategoryAdminMixin, AllinkTeaserAdminMixin,
                     TranslatableAdmin, SortableAdmin):
    exclude = ('lead',)
    readonly_fields = ('is_currently_open',)
    list_display = ('title', 'status', 'all_categories_column',)

    def get_fieldsets(self, request, obj=None):
        fieldsets = (
            (None, {
                'fields': (
                    'status',
                    'title',
                    'slug',
                    'subtitle',
                    ('lat', 'lng',),
                    ('street', 'street_nr',),
                    'street_additional',
                    ('zip_code', 'place',),
                    'country',
                    ('phone', 'mobile',),
                    ('email', 'fax',),
                    'website',
                    'map_link',
                    'commercial_register_entry',
                    'preview_image',
                    'opening_hours_display',
                )
            }),
            ('Opening hours (Detailed)', {
                'classes': ('collapse',),
                'fields': (
                    'is_currently_open',
                    'mon',
                    'mon_afternoon',
                    'tue',
                    'tue_afternoon',
                    'wed',
                    'wed_afternoon',
                    'thu',
                    'thu_afternoon',
                    'fri',
                    'fri_afternoon',
                    'sat',
                    'sat_afternoon',
                    'sun',
                    'sun_afternoon'
                ),
                'description': 'Format: "9:00-12:00  13:00-20:00"'
            }),
        )
        fieldsets += self.get_category_fieldsets()
        fieldsets += self.get_teaser_fieldsets()
        fieldsets += self.get_seo_fieldsets()
        return fieldsets

    def save_model(self, request, obj, form, change):
        if obj.value_has_changed_for_fields(["place", "zip_code", "street", "street_additional"]) \
                and obj.place and obj.zip_code and obj.street:
            msg = obj.geocode_location()
            if not msg:
                messages.warning(request, msg)
        obj.save()



from cms.models import CMSPlugin
from django.db import models
from filer.fields.image import FilerImageField


class AllinkQuotePlugin(CMSPlugin):
    text = models.TextField(
        'Quote Text',
    )

    author = models.CharField(
        'Author Name',
        max_length=255,
        blank=True,
        null=True
    )

    author_description = models.CharField(
        'Author Description',
        max_length=255,
        blank=True,
        null=True
    )

    author_image = FilerImageField(
        verbose_name="Author Image",
        on_delete=models.PROTECT,
        null=True,
        blank=True
    )

    def __str__(self):
        return self.author



# -*- coding: utf-8 -*-
from parler.managers import TranslatableQuerySet


class AllinkBaseModelQuerySet(TranslatableQuerySet):

    def active(self):
        return self.filter(status=1)

    def filter_by_categories(self, categories):
        return self.active() \
            .filter(categories__in=categories) \
            .distinct()

    def filter_by_category(self, category):
        return self.active() \
            .filter(categories=category) \
            .distinct()

    # ORDERING
    def latest(self):
        return self.active() \
            .order_by('-created', 'id') \
            .distinct('created', 'id')

    def earliest(self):
        return self.active() \
            .order_by('created', 'id').distinct('created', 'id')

    # A-Z
    def title_asc(self):
        return self.active() \
            .order_by('translations__title', 'id') \
            .distinct('translations__title', 'id')

    # Z-A
    def title_desc(self):
        return self.active() \
            .order_by('-translations__title', 'id') \
            .distinct('translations__title', 'id')


AllinkBaseModelManager = AllinkBaseModelQuerySet.as_manager


class AllinkCategoryModelQuerySet(AllinkBaseModelQuerySet):

    def category(self):
        return self.active() \
            .order_by('categories__tree_id', 'categories__lft', 'translations__title') \
            .distinct()


AllinkCategoryModelManager = AllinkCategoryModelQuerySet.as_manager



# Generated by Django 2.1.8 on 2019-07-02 17:18

import django.contrib.postgres.fields
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('cms', '0022_auto_20180620_1551'),
    ]

    operations = [
        migrations.CreateModel(
            name='AllinkSocialIconContainerPlugin',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, related_name='allink_social_icon_allinksocialiconcontainerplugin', serialize=False, to='cms.CMSPlugin')),
                ('project_css_classes', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(blank=True, max_length=50, null=True), blank=True, null=True, size=None)),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin',),
        ),
        migrations.CreateModel(
            name='AllinkSocialIconPlugin',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, related_name='allink_social_icon_allinksocialiconplugin', serialize=False, to='cms.CMSPlugin')),
                ('title', models.CharField(blank=True, help_text='SEO text (not visible) e.g. Follow allink on Instagram', max_length=255, null=True, verbose_name='Title')),
                ('icon', models.CharField(max_length=50, verbose_name='Icon')),
                ('link', models.URLField(verbose_name='Link')),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin',),
        ),
    ]



import tempfile
import os
from django.test import TestCase
from unittest import mock
from distutils.errors import DistutilsFileError
from ..utils import get_path, copy_dir, create_new_app, replace_strings, rename, fork_allink_app


class CustomisationUtilsTestCase(TestCase):
    dummy_app_path = 'allink_core/core/customisation/dummy_new_app'
    app_label = 'new_app'
    model_name = 'NewApp'

    def test_get_path_from_module(self):
        import django
        django_dirname = os.path.dirname(django.db.models.__file__)
        path_from_module_string = get_path('django.db.models')

        self.assertEqual(path_from_module_string, django_dirname)

    def test_get_path_from_module_not_found(self):
        with self.assertRaisesRegex(ModuleNotFoundError, "No module named 'some_model'"):
            get_path('some_model.something')

    def test_copy_dummy_dir_already_exists(self):
        with tempfile.TemporaryDirectory(prefix='temp_apps') as temp_apps_dir:
            apps_dir = temp_apps_dir
            with self.assertRaisesRegex(OSError, "'{}' directory already exists!".format(apps_dir)):
                copy_dir(dummy_app=self.dummy_app_path, app_path=apps_dir)

    def test_copy_dummy_dir_wrong_dummy_path(self):
        wrong_dummy_path = 'hello'
        with tempfile.TemporaryDirectory(prefix='temp_apps') as temp_apps_dir:
            apps_dir = os.path.join(temp_apps_dir, self.app_label)
            with self.assertRaisesRegex(DistutilsFileError, "cannot copy tree '{}': not a directory".format(wrong_dummy_path)):
                copy_dir(dummy_app=wrong_dummy_path, app_path=apps_dir)

    def test_copy_dummy_dir_all_files_copied(self):
        with tempfile.TemporaryDirectory(prefix='temp_apps') as temp_apps_dir:
            full_temp_path = os.path.join(temp_apps_dir, self.app_label)
            copy_dir(dummy_app=self.dummy_app_path, app_path=full_temp_path)
            total_file_count = sum([len(files) for r, d, files in os.walk(full_temp_path)])
            expected_file_count = 23
            self.assertEqual(total_file_count, expected_file_count)

    def test_rename_dummy_classes_in_one_file(self):
        with tempfile.TemporaryDirectory(prefix='temp_apps') as temp_apps_dir:
            full_temp_path = os.path.join(temp_apps_dir, self.app_label)
            copy_dir(dummy_app=self.dummy_app_path, app_path=full_temp_path)

            new_file = os.path.join(full_temp_path, 'models.py')

            replace = {
                'dummy_app': self.app_label,
                'DummyApp': self.model_name,
                'dummy-app': 'new-app',
            }

            replace_strings(new_file, replace)

            # test some strings which should be in this file
            with open(new_file) as f:
                s = f.read()
                self.assertIn('class NewApp(', s)
                self.assertIn('from .managers import NewAppManager', s)
                self.assertIn('new_app.NewApp', s)
                self.assertNotIn('dummy_app', s)
                self.assertNotIn('DummyApp', s)

    def test_rename_dir_or_file_one_file(self):
        with tempfile.TemporaryDirectory(prefix='temp_apps') as temp_apps_dir:
            full_temp_path = os.path.join(temp_apps_dir, self.app_label)
            copy_dir(dummy_app=self.dummy_app_path, app_path=full_temp_path)

            replace = {
                'dummy_app': self.app_label,
                'dummyapp': self.model_name.lower(),
            }
            # file
            new_file = os.path.join(full_temp_path, 'templates', 'dummy_app', 'dummyapp_detail.html')
            rename(path=new_file, replace=replace)
            renamed_file = os.path.join(full_temp_path, 'templates', 'dummy_app', 'newapp_detail.html')
            self.assertTrue(os.path.isfile(renamed_file))

            # dir
            new_dir = os.path.join(full_temp_path, 'templates', 'dummy_app')
            rename(path=new_dir, replace=replace)
            renamed_dir = os.path.join(full_temp_path, 'templates', 'new_app')
            self.assertTrue(os.path.isdir(renamed_dir))


class CustomisationNewAppTestCase(TestCase):
    dummy_app = 'allink_core.core.customisation.dummy_new_app'
    app_label = 'new_app'
    model_name = 'NewApp'

    @mock.patch('allink_core.core.customisation.utils.replace_strings')
    def test_create_new_app_all_files_string_replaced(self, mock_replace_strings):
        with tempfile.TemporaryDirectory(prefix='temp_apps') as temp_apps_dir:
            full_temp_path = os.path.join(temp_apps_dir, self.app_label)
            create_new_app(
                dummy_app=self.dummy_app,
                app_path=full_temp_path,
                model_name=self.model_name,
                app_label=self.app_label
            )

            expected_file_count = 23
            self.assertEqual(mock_replace_strings.call_count, expected_file_count)

    @mock.patch('allink_core.core.customisation.utils.rename')
    def test_create_new_app_all_renamed(self, mock_rename_file):
        with tempfile.TemporaryDirectory(prefix='temp_apps') as temp_apps_dir:
            full_temp_path = os.path.join(temp_apps_dir, self.app_label)
            create_new_app(
                dummy_app=self.dummy_app,
                app_path=full_temp_path,
                model_name=self.model_name,
                app_label=self.app_label
            )

            expected_file_count = 28
            self.assertEqual(mock_rename_file.call_count, expected_file_count)

    def test_create_new_app_no_dummy_app_names(self):
        with tempfile.TemporaryDirectory(prefix='temp_apps') as temp_apps_dir:
            full_temp_path = os.path.join(temp_apps_dir, self.app_label)

            create_new_app(
                dummy_app=self.dummy_app,
                app_path=full_temp_path,
                model_name=self.model_name,
                app_label=self.app_label
            )

            not_expected = ['dummy_app', 'dummyapp']
            all_dirs = list()
            all_files = list()
            for root, dirs, files in os.walk(full_temp_path):
                all_dirs.extend(dirs)
                all_files.extend(files)

            self.assertFalse([d for d in all_dirs if any(xs in d for xs in not_expected)])
            self.assertFalse([f for f in all_files if any(xs in f for xs in not_expected)])


class CustomisationForkAppTestCase(TestCase):
    dummy_app = 'allink_core.core.customisation.dummy_fork_app_minimum'
    app_label = 'news'

    expected_dirs = ['migrations', 'tests']
    expected_files = [
        'admin.py',
        'cms_apps.py',
        'cms_menus.py',
        'cms_plugins.py',
        'cms_toolbars.py',
        'config.py',
        'managers.py',
        'models.py',
    ]
    not_expected = ['dummy_app', 'dummyapp', 'DummyApp']

    def test_fork_allink_no_allink_app_with_name(self):
        with tempfile.TemporaryDirectory(prefix='temp_apps') as temp_apps_dir:
            full_temp_path = os.path.join(temp_apps_dir, self.app_label)

            with self.assertRaisesRegex(ValueError, 'There is no allink_core app'):
                fork_allink_app(
                    dummy_app=self.dummy_app,
                    app_path=full_temp_path,
                    app_label='wrong_app_label'
                )

    def test_fork_allink_app_no_dummy_app_names(self):
        with tempfile.TemporaryDirectory(prefix='temp_apps') as temp_apps_dir:
            full_temp_path = os.path.join(temp_apps_dir, self.app_label)

            fork_allink_app(
                dummy_app=self.dummy_app,
                app_path=full_temp_path,
                app_label=self.app_label
            )

            all_dirs = list()
            all_files = list()
            for root, dirs, files in os.walk(full_temp_path):
                all_dirs.extend(dirs)
                all_files.extend(files)

            self.assertFalse([d for d in all_dirs if any(xs in d for xs in self.not_expected)])
            self.assertFalse([f for f in all_files if any(xs in f for xs in self.not_expected)])

    def test_fork_allink_all_files(self):
        with tempfile.TemporaryDirectory(prefix='temp_apps') as temp_apps_dir:
            full_temp_path = os.path.join(temp_apps_dir, self.app_label)

            fork_allink_app(
                dummy_app=self.dummy_app,
                app_path=full_temp_path,
                app_label=self.app_label
            )

            all_dirs = list()
            all_files = list()
            for root, dirs, files in os.walk(full_temp_path):
                all_dirs.extend(dirs)
                all_files.extend(files)

            self.assertTrue([d for d in all_dirs if any(xs in d for xs in self.expected_dirs)])
            self.assertTrue([f for f in all_files if any(xs in f for xs in self.expected_files)])

    def test_rename_dummy_naming(self):
        with tempfile.TemporaryDirectory(prefix='temp_apps') as temp_apps_dir:
            full_temp_path = os.path.join(temp_apps_dir, self.app_label)

            fork_allink_app(
                dummy_app=self.dummy_app,
                app_path=full_temp_path,
                app_label=self.app_label
            )

            for root, dirs, files in os.walk(full_temp_path):
                # test strings which should not be in this file
                for file in files:
                    if file in self.expected_files:
                        with open(os.path.join(root, file), encoding='utf-8') as f:
                            s = f.read()
                            self.assertFalse(any(string in s for string in self.not_expected))



# -*- coding: utf-8 -*-
import re
from django.conf import settings
from django.http import HttpResponsePermanentRedirect


class AllinkUrlRedirectMiddleware:
    """
    This middleware lets you match a specific url and redirect the request to a new url.

    You keep a tuple of url regex pattern/url redirect tuples on your site settings, example:

    URL_REDIRECTS = (
        (r'www\.example\.com/hello/$', 'http://hello.example.com/'),  # noqa
        (r'www\.example2\.com/$', 'http://www.example.com/example2/'),  # noqa
    )
    """
    def __init__(self, get_response):
        self.get_response = get_response

    def __call__(self, request):
        host = request.META['HTTP_HOST'] + request.META['PATH_INFO']
        if hasattr(settings, 'URL_REDIRECTS'):
            for url_pattern, redirect_url in settings.URL_REDIRECTS:
                regex = re.compile(url_pattern)
                if regex.match(host):
                    return HttpResponsePermanentRedirect(redirect_url)
        else:
            return self.get_response(request)



# -*- coding: utf-8 -*-
import factory
from django.conf import settings
from allink_core.core.test.factories import FilerImageFactory
from ..models import Config, AllinkPageExtension, AllinkTitleExtension


class ConfigFactory(factory.DjangoModelFactory):
    class Meta:
        model = Config

    default_og_image = factory.SubFactory(FilerImageFactory)
    theme_color = None
    mask_icon_color = None
    msapplication_tilecolor = None
    google_site_verification = 'google-site-verification-code'
    default_to_email = 'default_to_email@email.com'
    default_from_email = 'default_from_email@email.com'

    @factory.post_generation
    def post(self, create, extracted, **kwargs):
        for lang, _ in settings.LANGUAGES:
            self.set_current_language(lang)
            self.default_base_title = 'default_base_title_{}'.format(lang)
            self.newsletter_lead = 'newsletter_lead_{}'.format(lang)
            self.newsletter_signup_link = 'newsletter_signup_link_{}'.format(lang)
            self.newsletter_declaration_of_consent = 'newsletter_declaration_of_consent_{}'.format(lang)
            self.save()


class AllinkPageExtensionFactory(factory.DjangoModelFactory):
    class Meta:
        model = AllinkPageExtension

    extended_object = None
    og_image = factory.SubFactory(FilerImageFactory)
    teaser_image = factory.SubFactory(FilerImageFactory)


class AllinkTitleExtensionFactory(factory.DjangoModelFactory):
    class Meta:
        model = AllinkTitleExtension

    extended_object = None
    og_title = 'og title'
    og_description = 'og description'
    teaser_title = 'teaser title'
    teaser_technical_title = 'teaser technical title'
    teaser_description = 'teaser description'
    teaser_link_text = 'teaser link text'



from django.test.testcases import TestCase
from django.test.client import RequestFactory
from django.template import Template, RequestContext
from cms import api
from allink_core.apps.news.tests.factories import NewsFactory
from .factories import ConfigFactory
from ..utils import get_meta_page_title, get_fallback


class AllinkSEOMetaTestCase(TestCase):

    def setUp(self):
        self.page_de = api.create_page(
            title='page title',
            template='default.html',
            language='de',
            published=True,
        )
        self.allink_config = ConfigFactory()
        self.entry_1 = NewsFactory()

    def render_template(self, string, request, context=None):
        context = context or {}
        context = RequestContext(request, context)
        context.request = request
        return Template(string).render(context)

    def test_rendered_template_with_page_contains_correct_values(self):
        request = RequestFactory().get(self.page_de.get_absolute_url())
        request.current_page = self.page_de

        rendered_template = self.render_template(
            string='{% load allink_meta_tags %} {% render_meta_og %}',
            request=request,
        )
        self.assertIn(get_meta_page_title(self.page_de), rendered_template)
        self.assertIn(get_fallback(self.page_de, 'meta_title'), rendered_template)
        self.assertIn(get_fallback(self.page_de, 'meta_description') or '', rendered_template)
        self.assertIn(getattr(get_fallback(self.page_de, 'meta_image'), 'url'), rendered_template)
        self.assertIn(self.allink_config.google_site_verification, rendered_template)

    def test_rendered_template_with_page_contains_correct_overwitten_values(self):
        request = RequestFactory().get(self.page_de.get_absolute_url())
        request.current_page = self.page_de

        rendered_template = self.render_template(
            string='''
            {% load allink_meta_tags %} 
            {% render_meta_og overwrite_dict="{'meta_title': 'Hello', 'meta_description': 'Some Text', 'meta_image_url':'www.foo.ch/image.jpg'}" %}''',
            request=request,
        )
        self.assertIn('Hello', rendered_template)
        self.assertIn(get_fallback(self.page_de, 'meta_title'), rendered_template)
        self.assertIn('Some Text', rendered_template)
        self.assertIn('www.foo.ch/image.jpg', rendered_template)
        self.assertIn(self.allink_config.google_site_verification, rendered_template)



from django.urls import include, path
from django.contrib import admin
from django.conf.urls.i18n import i18n_patterns
from django.contrib.sitemaps.views import sitemap as sitemap_view
from django.views.i18n import JavaScriptCatalog
from allink_core.core.sitemap import CMSHrefLangSitemap
from allink_core.apps.news.sitemaps import NewsSitemap

sitemaps = {
    'cms': CMSHrefLangSitemap,
    'news': NewsSitemap,
}

urlpatterns = [
    path('sitemap.xml', sitemap_view, {'sitemaps': sitemaps}),
    path('styleguide/', include('allink_core.core_apps.allink_styleguide.urls', namespace='styleguide')),
    path('cms-api/', include('allink_core.core_apps.allink_cms.urls', namespace='cms_api')),

] + i18n_patterns(
    path('jsi18n/', JavaScriptCatalog.as_view(domain='django'), name='javascript-catalog'),
    path('sitemap.xml', sitemap_view, {'sitemaps': sitemaps}),
    path('admin/', admin.site.urls),
    path('', include('cms.urls')),
)



# Generated by Django 2.1.8 on 2019-07-02 17:18

import cms.models.fields
import django.contrib.postgres.fields
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('cms', '0022_auto_20180620_1551'),
    ]

    operations = [
        migrations.CreateModel(
            name='AllinkTeaserPlugin',
            fields=[
                ('link_object_id', models.IntegerField(help_text='To which object directs the url.', null=True)),
                ('link_model', models.CharField(help_text='Dotted Path to referenced Model', max_length=300, null=True)),
                ('link_url_name', models.CharField(help_text='Name of the App-URL to use.', max_length=64, null=True)),
                ('link_url_kwargs', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(blank=True, max_length=50, null=True), blank=True, help_text='Keyword arguments used to reverse url.', null=True, size=None)),
                ('template', models.CharField(max_length=50, verbose_name='Template')),
                ('cmsplugin_ptr', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, related_name='allink_teaser_allinkteaserplugin', serialize=False, to='cms.CMSPlugin')),
                ('link_apphook_page', cms.models.fields.PageField(help_text='If provided, overrides the external link.', null=True, on_delete=django.db.models.deletion.PROTECT, related_name='allink_teaser_allinkteaserplugin_app_legacy_redirects', to='cms.Page', verbose_name='New Apphook-Page')),
                ('link_page', cms.models.fields.PageField(help_text='If provided, overrides the external link and New Apphook-Page.', null=True, on_delete=django.db.models.deletion.PROTECT, to='cms.Page', verbose_name='New Page')),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin', models.Model),
        ),
    ]



# -*- coding:utf-8 -*-
from __future__ import unicode_literals
from django import template

register = template.Library()


@register.filter('link_attribute_string')
def link_attribute_string(instance, request=None):
    attributes = ''
    attributes += 'target=_blank' if instance.new_window_enabled else ''
    # https://developers.google.com/web/tools/lighthouse/audits/noopener
    attributes += ' rel=noopener' if instance.new_window_enabled else ''
    attributes += ' data-trigger-form-modal' if instance.form_modal_enabled else ''
    attributes += ' data-trigger-image-modal' if instance.image_modal_enabled else ''
    attributes += ' data-trigger-default-modal' if instance.default_modal_enabled else ''
    attributes += ' data-default-modal-variation=video-modal data-default-modal-content-container-id=video-modal-{}'\
        .format(instance.id) if (hasattr(instance, 'template')
                                 and getattr(instance, 'template') == 'video_embedded_link') \
        or (hasattr(instance, 'template') and getattr(instance, 'template')
            == 'video_file_link') else ''

    if instance.image_modal_enabled or instance.default_modal_enabled or instance.form_modal_enabled:
        attributes += ' data-modal-escape-close-method-enabled=true' \
            if hasattr(instance, 'data_modal_escape_close_enabled') \
            and instance.data_modal_escape_close_enabled else ''
        attributes += ' data-modal-overlay-close-method-enabled=true' \
            if hasattr(instance, 'data_modal_overlay_close_enabled') \
            and instance.data_modal_overlay_close_enabled else ''
        attributes += ' data-modal-button-close-method-enabled=true' \
            if hasattr(instance, 'data_modal_button_close_enabled') \
            and instance.data_modal_button_close_enabled else ''

    attributes += ' data-trigger-softpage' if instance.softpage_enabled else ''
    attributes += ' data-smooth-scroll' if instance.link_anchor else ''
    attributes += ' data-cms-page' if instance.link_page and instance.softpage_enabled else ''
    attributes += ' role=button' if hasattr(instance, "type") and instance.type == 'btn' else ''
    attributes += ' '.join([' {}={}'.format(k, v) if v else ' {}'.format(k) for k, v in
                            instance.link_attributes.items()]) if instance.link_attributes else ''
    return attributes


@register.filter('link_classes')
def link_classes(instance):
    classes = ''
    if hasattr(instance, 'type'):
        if instance.type == 'btn':
            classes += ' btn'
            if instance.btn_context:
                classes += ' btn-{}'.format(instance.btn_context)
            if instance.btn_size:
                classes += ' btn-{}'.format(instance.btn_size)
            if instance.btn_block:
                classes += ' btn-{}'.format(instance.btn_block)
        else:
            classes += ' text'
    return classes


@register.simple_tag
def get_absolute_url(obj, application_namespace=None):
    """
    :param obj:
    a instance of a model which inherits from AllinkBaseModel
    :param application_namespace:
    String, either defined in some urls.py file
    or in most cases directly in a CMS-Page (e.g. news_engimatt or news_leafs)
    :return:
    the absolute url to the detail view

    example:
    {% get_absolute_url object instance.apphook_page.application_namespace %}
    """
    return obj.get_absolute_url(application_namespace=application_namespace)



import pickle
from django.test.testcases import TransactionTestCase, override_settings
from unittest.mock import patch, call
from django.conf import settings
from parler.utils.context import switch_language
from ..models import Config
from .factories import ConfigFactory



MEMCACHED_CACHES = {
    'default': {
        'BACKEND': 'django.core.cache.backends.locmem.LocMemCache',
        'LOCATION': 'unique-snowflake',
    }
}


class AllinkConfigTestCase(TransactionTestCase):

    def setUp(self):
        self.allink_config = ConfigFactory()

    def test_config_language_no_cache(self):
        for lang, _ in settings.LANGUAGES:
            with switch_language(self.allink_config, lang):
                self.assertEqual(self.allink_config.newsletter_signup_link, 'newsletter_signup_link_{}'.format(lang))

    def test_config_language_get_cache_key(self):
        for lang, _ in settings.LANGUAGES:
            with switch_language(self.allink_config, lang):
                self.assertEqual(self.allink_config.get_cache_key(lang), 'solo:config_{}'.format(lang))

    @patch('django.core.cache.cache.set')
    def test_config_language_set_to_cache(self, mock_cache_set):
        """
        every language will be set to cache, so for one language ('en') all languages (3) will be set to cache.
        checks also if correct translated object "allink_config" gets saved to cache
        """
        with switch_language(self.allink_config, 'en'):
            self.allink_config.set_to_cache()
            expected_calls = [call('solo:config_{}'.format('en'), pickle.dumps(self.allink_config), 15552000)]
            mock_cache_set.assert_has_calls(expected_calls)

            with switch_language(self.allink_config, 'de'):
                expected_calls = [call('solo:config_{}'.format('de'), pickle.dumps(self.allink_config), 15552000)]
                mock_cache_set.assert_has_calls(expected_calls)

            with switch_language(self.allink_config, 'fr'):
                expected_calls = [call('solo:config_{}'.format('fr'), pickle.dumps(self.allink_config), 15552000)]
                mock_cache_set.assert_has_calls(expected_calls)

        self.assertEqual(mock_cache_set.call_count, len(settings.LANGUAGES))  # for each language total: 3 times

    @patch('django.core.cache.cache.get')
    def test_get_solo(self, mock_cache_get):
        for lang, _ in settings.LANGUAGES:
            mock_cache_get.return_value = pickle.dumps(self.allink_config)
            with switch_language(self.allink_config, lang):
                self.assertEqual(self.allink_config, Config.get_solo())

    @override_settings(CACHES=MEMCACHED_CACHES)
    def test_get_solo_meme_cache_get_solo(self):
        with switch_language(self.allink_config, 'en'):
            self.allink_config.set_to_cache()
            self.assertEqual(self.allink_config, Config.get_solo())

            with switch_language(self.allink_config, 'de'):
                self.assertEqual(self.allink_config, Config.get_solo())

            with switch_language(self.allink_config, 'fr'):
                self.assertEqual(self.allink_config, Config.get_solo())

    @patch('django.core.cache.cache.get')
    def test_get_solo_not_cached(self, mock_cache_get):
        for lang, _ in settings.LANGUAGES:
            mock_cache_get.return_value = None
            with switch_language(self.allink_config, lang):
                self.assertEqual(self.allink_config, Config.get_solo())

    @patch('cms.cache.invalidate_cms_page_cache')
    @patch('django.core.cache.cache.clear')
    @patch('menus.menu_pool.menu_pool.clear')
    def test_save_invalidate_cms_page_cache(self, mock_menu_pool_clear, mock_cache_clear, mock_invalidate_cms_page_cache):
        self.allink_config.save()
        mock_invalidate_cms_page_cache.assert_called_once()
        mock_cache_clear.assert_called_once()
        mock_menu_pool_clear.assert_called_once()



# -*- coding: utf-8 -*-
from django.core.management.base import BaseCommand
from django.core.cache import cache


class Command(BaseCommand):
    """
    e.g.:
    ./manage.py clearcache"
    """
    help = ('Clears the hole application cache.')

    def handle(self, *args, **options):
        cache.clear()



# -*- coding: utf-8 -*-
from django import forms
from django.conf import settings
from cms.models import CMSPlugin
from cms.plugin_base import CMSPluginBase
from cms.plugin_pool import plugin_pool
from webpack_loader.utils import get_files

from allink_core.core.utils import get_additional_choices
from allink_core.core.forms.fields import ColorField
from allink_core.core_apps.allink_content.models import AllinkContentPlugin, AllinkContentColumnPlugin
from allink_core.core.admin.mixins import AllinkMediaAdminMixin


class AllinkContentPluginForm(forms.ModelForm):
    class Meta:
        model = AllinkContentPlugin
        exclude = ('page', 'position', 'placeholder', 'language', 'plugin_type')

    def __init__(self, *args, **kwargs):
        super(AllinkContentPluginForm, self).__init__(*args, **kwargs)
        self.fields['template'] = forms.CharField(
            label='Template',
            widget=forms.Select(choices=self.instance.get_template_choices()),
            required=True,
        )
        if get_additional_choices('CONTENT_TITLE_CHOICES'):
            self.fields['title_size'] = forms.CharField(
                label='Section Title Size',
                widget=forms.Select(
                    choices=get_additional_choices('CONTENT_TITLE_CHOICES'),
                ),
                initial=settings.CONTENT_TITLE_CHOICES_DEFAULT,
                required=False,
            )
        else:
            self.fields['title_size'] = forms.CharField(widget=forms.HiddenInput(), required=False)

        self.fields['bg_color'] = ColorField(
            label='Background color',
            required=False,
        )

        if get_additional_choices('CONTENT_CSS_CLASSES'):
            self.fields['project_css_classes'] = forms.MultipleChoiceField(
                widget=forms.CheckboxSelectMultiple(),
                label='Predifined variations',
                choices=get_additional_choices('CONTENT_CSS_CLASSES'),
                required=False,
            )
        if get_additional_choices('CONTENT_SPACINGS'):
            self.fields['project_css_spacings_top_bottom'] = forms.ChoiceField(
                label='Spacings top & bottom',
                choices=get_additional_choices('CONTENT_SPACINGS', blank=True),
                required=False,
            )
        if get_additional_choices('CONTENT_SPACINGS'):
            self.fields['project_css_spacings_top'] = forms.ChoiceField(
                label='Spacings top',
                choices=get_additional_choices('CONTENT_SPACINGS', blank=True),
                required=False,
            )
        if get_additional_choices('CONTENT_SPACINGS'):
            self.fields['project_css_spacings_bottom'] = forms.ChoiceField(
                label='Spacings bottom',
                choices=get_additional_choices('CONTENT_SPACINGS', blank=True),
                required=False,
            )

    def clean(self):
        cleaned_data = super(AllinkContentPluginForm, self).clean()
        if self.instance.pk:
            # if column count is not the same, dont allow template to change
            if self.instance.get_template_column_count(self.instance.template) != self.instance.get_template_column_count(cleaned_data['template']):  # noqa
                self.add_error('template', 'You can only change the template if it'
                                           ' has the same amount of columns as the previous template.')
        return cleaned_data


class AllinkContentColumnPluginForm(forms.ModelForm):
    class Meta:
        model = AllinkContentColumnPlugin
        exclude = ('title', 'page', 'position', 'placeholder', 'language', 'plugin_type')

    def __init__(self, *args, **kwargs):
        super(AllinkContentColumnPluginForm, self).__init__(*args, **kwargs)
        parent_column_amount = AllinkContentPlugin.get_template_column_count(kwargs.get('instance').template)
        self.fields['order_mobile'].widget = forms.Select(choices=enumerate(range(1, parent_column_amount + 1)))


@plugin_pool.register_plugin
class CMSAllinkContentPlugin(AllinkMediaAdminMixin, CMSPluginBase):
    model = AllinkContentPlugin
    name = 'Content'
    module = 'Generic'
    render_template = "allink_content/default/content.html"
    allow_children = True
    child_classes = ['ContentColumnPlugin']
    form = AllinkContentPluginForm

    fieldsets = (
        (None, {
            'fields': (
                'title',
                'title_size',
                'template',
            ),
        }),
        ('Section Options', {
            'classes': ('collapse',),
            'fields': [
                'container_enabled',
                'inverted_colors_enabled',
                'overlay_enabled',
                'bg_color',
            ]
        }),
        ('Spacings', {
            'classes': ('collapse',),
            'fields': [
                'project_css_spacings_top_bottom',
                'project_css_spacings_top',
                'project_css_spacings_bottom',
            ]
        }),
        ('Background Image (full width)', {
            'classes': ('collapse',),
            'fields': (
                'bg_image_outer_container',
                'dynamic_height_enabled',
            )
        }),
        ('Background Video (Important: Only works if all fields are set)', {
            'classes': ('collapse',),
            'fields': (
                'video_file',
                'video_poster_image',
                'video_mobile_image',
            )
        }),
        ('Advanced Options', {
            'classes': ('collapse',),
            'fields': (
                'project_css_classes',
                'anchor',
                'ignore_in_pdf',
            )
        })
    )

    @classmethod
    def get_render_queryset(cls):
        return cls.model._default_manager.all()

    def save_model(self, request, obj, form, change):
        response = super(CMSAllinkContentPlugin, self).save_model(request, obj, form, change)
        if obj.numchild == 0:
            column_amount = AllinkContentPlugin.get_template_column_count(form.cleaned_data['template'])

            for x in range(int(column_amount)):
                col = AllinkContentColumnPlugin(
                    parent=obj,
                    placeholder=obj.placeholder,
                    language=obj.language,
                    position=CMSPlugin.objects.filter(parent=obj).count(),
                    order_mobile=CMSPlugin.objects.filter(parent=obj).count(),
                    plugin_type=CMSAllinkContentColumnPlugin.__name__
                )
                col.save()
        return response

    def render(self, context, instance, placeholder):
        return super().render(context, instance, placeholder)


@plugin_pool.register_plugin
class CMSAllinkContentColumnPlugin(AllinkMediaAdminMixin, CMSPluginBase):
    model = AllinkContentColumnPlugin
    name = "Column"
    module = 'Generic'
    render_template = "allink_content/default/column.html"
    parent_classes = ["AllinkContentPlugin"]
    allow_children = True
    child_classes = settings.ALLINK_CONTENT_PLUGIN_CHILD_CLASSES
    form = AllinkContentColumnPluginForm
    require_parent = True

    disable_copyable_menu = True
    disable_cutable_menu = True
    disable_deletable_menu = True

    def has_delete_permission(self, request, obj=None):
        return False

    def save_model(self, request, obj, form, change):

        if 'order_mobile' in form.changed_data:
            parent = obj.parent.get_plugin_instance()[0]
            for column in parent.get_children():
                if column.plugin_type == 'CMSAllinkContentColumnPlugin':
                    #  change the column which had the same ordering before
                    #  to the value which our changed column had before
                    child_column = column.get_plugin_instance()[0]
                    if child_column.order_mobile == form.cleaned_data.get('order_mobile'):
                        child_column.order_mobile = form.initial.get('order_mobile')
                        child_column.save()
        return super(CMSAllinkContentColumnPlugin, self).save_model(request, obj, form, change)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import os
import re
import sys
from setuptools import setup, find_packages


def get_version(*file_paths):
    """Retrieves the version from allink_core/__init__.py"""
    filename = os.path.join(os.path.dirname(__file__), *file_paths)
    version_file = open(filename).read()
    version_match = re.search(r"^__version__ = ['\"]([^'\"]*)['\"]",
                              version_file, re.M)
    if version_match:
        return version_match.group(1)
    raise RuntimeError('Unable to find version string.')


version = get_version("allink_core", "__init__.py")


if sys.argv[-1] == 'publish':
    try:
        import wheel
        print("Wheel version: ", wheel.__version__)
    except ImportError:
        print('Wheel library missing. Please run "pip install wheel"')
        sys.exit()
    os.system('python setup.py sdist bdist_wheel')
    sys.exit()

readme = open('README.md').read()

# https://pypi.python.org/pypi?%3Aaction=list_classifiers
CLASSIFIERS = [
    'Development Status :: 5 - Production/Stable',
    'Environment :: Web Environment',
    'Intended Audience :: Developers',
    'License :: OSI Approved :: BSD License',
    'Operating System :: OS Independent',
    'Framework :: Django',
    'Framework :: Django :: 2.0',
    'Framework :: Django :: 2.1',
    'Framework :: Django :: 2.2',
    'Programming Language :: Python',
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    'Topic :: Software Development',
    'Topic :: Software Development :: Libraries :: Application Frameworks',
]

INSTALL_REQUIREMENTS = [
    'Django>=2.0,<3.0',
]

setup(
    name='allink-core',
    version=version,
    description='A collection of apps used in allink cms-projects.',
    long_description=readme,
    long_description_content_type='text/markdown',
    author='allink AG and contributors',
    author_email='itcrowd@allink.ch',
    url='http://github.com/allink/allink-core/',
    license='BSD License',
    platforms=['OS Independent'],
    packages=find_packages(exclude=['tests', 'tests.*', ]),
    classifiers=CLASSIFIERS,
    install_requires=INSTALL_REQUIREMENTS,
    include_package_data=True,
    zip_safe=False,
)



# -*- coding: utf-8 -*-
from django.contrib import admin
from adminsortable.admin import SortableAdmin

from allink_core.core.loading import get_model
from parler.admin import TranslatableAdmin
from allink_core.core.admin import AllinkMediaAdminMixin, AllinkSEOAdminMixin, \
    AllinkCategoryAdminMixin, AllinkTeaserAdminMixin

People = get_model('people', 'People')


@admin.register(People)
class PeopleAdmin(AllinkMediaAdminMixin, AllinkSEOAdminMixin, AllinkCategoryAdminMixin, AllinkTeaserAdminMixin,
                  TranslatableAdmin, SortableAdmin):
    search_fields = ('first_name', 'last_name',)
    list_display = ('first_name', 'last_name', 'status', 'all_categories_column', 'created', 'modified',)
    view_on_site = False

    def get_fieldsets(self, request, obj=None):
        fieldsets = (
            (None, {
                'fields': (
                    'status',
                    ('first_name', 'last_name'),
                    'job_function',
                    'preview_image',
                    ('email', 'website'),
                    'company_name',
                    ('phone', 'mobile', 'fax'),
                    ('street', 'street_nr'),
                    'street_additional',
                    ('place', 'zip_code'),
                    'country',
                    'slug',
                )
            }),
        )
        fieldsets += self.get_category_fieldsets()
        fieldsets += self.get_teaser_fieldsets()
        fieldsets += self.get_seo_fieldsets()
        return fieldsets
